<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://juaala.com/
 * @since      1.0.0
 *
 * @package    Rsonline_Juaala
 * @subpackage Rsonline_Juaala/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Rsonline_Juaala
 * @subpackage Rsonline_Juaala/admin
 * @author     Juaala <info@juaala.com>
 */
class Rsonline_Juaala_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The file of this plugin.
	 *
	 * @since    1.0.3
	 * @access   private
	 * @var      string    $file_plugin    The file of this plugin.
	 */
	private $file_plugin;


	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $file_plugin, $version ) {

		$this->plugin_name = $plugin_name;
		$this->file_plugin = $file_plugin;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Rsonline_Juaala_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Rsonline_Juaala_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */


		$screen = get_current_screen();
		if ($screen->base == "toplevel_page_juaala-rso-settings-page") {
			$number_version = intval(str_replace(".", "", $this->version));
			if ($number_version<=104) {
				wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . '../public/assets/scss/style.php?p=rs_juaala.scss', array(), null, 'all');
			} else {
				wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . '../public/assets/scss/style.php?p=rs_juaalav2.scss', array(), null, 'all');
			}
			wp_enqueue_style('fontawesome', plugin_dir_url( __FILE__ ) . '../public/assets/fontawesome/css/all.min.css', array(),  $this->version, 'all');
		}

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Rsonline_Juaala_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Rsonline_Juaala_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		$screen = get_current_screen();
		if ($screen->base == "toplevel_page_juaala-rso-settings-page") {
			$number_version = intval(str_replace(".", "", $this->version));
			if ($number_version<=104) {
				wp_enqueue_script($this->plugin_name . '-js-bootstrap', plugin_dir_url ( __FILE__ ) . '../public/assets/vendor/bootstrap-5.0.2/dist/js/bootstrap.bundle.min.js', array('jquery'), $this->version, false);
			} else {
				wp_enqueue_script($this->plugin_name . '-js-bootstrap', plugin_dir_url ( __FILE__ ) . '../public/assets/vendor/bootstrap-5.2.3/dist/js/bootstrap.bundle.min.js', array('jquery'), $this->version, false);	
			}
			wp_enqueue_script($this->plugin_name . '-js-popper', plugin_dir_url ( __FILE__ ) . '../public/assets/vendor/popper.min.js', array(), $this->version, false);
		}
		
		wp_enqueue_media();
		wp_enqueue_script($this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/rsonline-juaala-admin.js', array('jquery'), $this->version, false);
		wp_localize_script($this->plugin_name, 'wp_ajax_vars', array(
			'ajax_url' => admin_url( 'admin-ajax.php' )
		));

	}

	function codemirror_enqueue_scripts($hook) {
		$cm_settings['codeEditor'] = wp_enqueue_code_editor(array('type' => 'text/css'));
		wp_localize_script('jquery', 'cm_settings', $cm_settings);
	 
		wp_enqueue_script('wp-theme-plugin-editor');
		wp_enqueue_style('wp-codemirror');
	}

	public function juaala_rso_add_admin_menu() {
		add_menu_page(
			__("Resales Online Settings",'rsonline-juaala'), 
			__("Resales Online Settings",'rsonline-juaala'), 
			'administrator', 
			'juaala-rso-settings-page' , 
			array( $this, 'admin_page_html' ),
			'dashicons-admin-multisite'
			);
	}

	public function juaala_rso_admin_init() {
		$this->init_tab_main();
		$this->init_tab_idioma();
		$this->init_tab_map();
		$this->init_tab_contact();
		$this->init_tab_pdf();
		$this->init_tab_styles();
	}

	public function admin_page_html() {
		$default_tab = null;
		$tab = isset($_GET['tab']) ? $_GET['tab'] : $default_tab;
	
	?>
		<div class="wrap">
			<!-- Print the page title -->
			<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
			<!-- Here are our tabs -->
			<nav class="nav-tab-wrapper">
				<a href="?page=juaala-rso-settings-page" class="nav-tab <?php if($tab===null):?>nav-tab-active<?php endif; ?>">
					<?php echo __("Connection with Resales Online",'rsonline-juaala') ?>
				</a>
				<a href="?page=juaala-rso-settings-page&tab=styles" class="nav-tab <?php if($tab==='styles'):?>nav-tab-active<?php endif; ?>">
					<?php echo __("Styles",'rsonline-juaala') ?>
				</a>
				<a href="?page=juaala-rso-settings-page&tab=map" class="nav-tab <?php if($tab==='map'):?>nav-tab-active<?php endif; ?>">
					<?php echo __("Integration with Map",'rsonline-juaala') ?>
				</a>
				<a href="?page=juaala-rso-settings-page&tab=contact" class="nav-tab <?php if($tab==='contact'):?>nav-tab-active<?php endif; ?>">
					<?php echo __("Integration with Contact Form 7",'rsonline-juaala') ?>
				</a>
				<a href="?page=juaala-rso-settings-page&tab=pdf" class="nav-tab <?php if($tab==='pdf'):?>nav-tab-active<?php endif; ?>">
					<?php echo __("PDF",'rsonline-juaala') ?>
				</a>
				<a href="?page=juaala-rso-settings-page&tab=language" class="nav-tab <?php if($tab==='language'):?>nav-tab-active<?php endif; ?>">
					<?php echo __("Language",'rsonline-juaala') ?>
				</a>
				<a href="?page=juaala-rso-settings-page&tab=doc" class="nav-tab <?php if($tab==='doc'):?>nav-tab-active<?php endif; ?>">
					<?php echo __("Documentation",'rsonline-juaala') ?>
				</a>
			</nav>
	
			<div class="tab-content">
				<?php switch($tab) :
					case 'styles':
						include('partials/styles_form.php');
						break;
					case 'map':
						include('partials/map_form.php');
						break;
					case 'contact':
						include('partials/contact_form.php');
						break;
					case 'pdf':
						include('partials/pdf_form.php');
						break;
					case 'language':
						include('partials/language_form.php');
						break;
					case 'doc':
							include('partials/doc_form.php');
							break;
					default:
						include('partials/main_form.php');
						break;
				endswitch; ?>
			</div>
		</div>
		 <?php
	}


	protected function init_tab_main() {
		add_settings_section( 'section-main', '', array($this,'section_main_callback'), 'resalesonline_settings_page_main' );

		add_settings_field( 'field-api-juaala', __("API KEY JUAALA",'rsonline-juaala'), array($this,'field_api_key_juaala_callback'), 'resalesonline_settings_page_main', 'section-main' );

		add_settings_field( 'field-one', __("API KEY",'rsonline-juaala'), array($this,'field_api_key_callback'), 'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-two', __("Client ID",'rsonline-juaala'), array($this,'field_client_id_callback'), 'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-five', __("Default filter ID Sales",'rsonline-juaala'), array($this,'field_default_filter_id_callback'), 'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-ten', __("Default filter ID Short Rentals",'rsonline-juaala'), array($this,'field_default_filter_id_short_callback'),'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-eleven', __("Default filter ID Long Rentals",'rsonline-juaala'), array($this,'field_default_filter_id_long_callback'),'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-twelve', __("Default filter ID Features",'rsonline-juaala'), array($this,'field_default_filter_id_features_callback'),'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-pdf-generator', __("Default filter ID PDF/JPG generator",'rsonline-juaala'), array($this,'field_pdf_filter_callback'),'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-include-only-areas', __("Include only Areas on filter API",'rsonline-juaala'), array($this,'field_include_only_areas_callback'), 'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-list-type-filter', __("Include only property type on search",'rsonline-juaala'), array($this,'field_list_type_filter_callback'), 'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-include-search-property-details-page', __("Include search in property details page",'rsonline-juaala'), array($this,'field_include_search_propery_details_page_callback'), 'resalesonline_settings_page_main', 'section-main' );

		add_settings_field( 'field-id-page-shortlist', __("Id page shortlist",'rsonline-juaala'), array($this,'field_include_id_page_shortlist_callback'), 'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-id-page-result-search', __("Id page result search",'rsonline-juaala'), array($this,'field_include_id_page_resultsearch_callback'), 'resalesonline_settings_page_main', 'section-main' );
		add_settings_field( 'field-id-page-property-details', __("Id page property details",'rsonline-juaala'), array($this,'field_include_id_page_property_details_callback'), 'resalesonline_settings_page_main', 'section-main' );


		add_settings_field( 'field-debug-mode-rsonline-juaala', '', array($this,'field_debug_mode_callback'), 'resalesonline_settings_page_main', 'section-main' );

		

		register_setting( 'rojuaala-settings-group-main', 'rojuaala-own-api-key' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-api-key' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-client-id' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-default-filter-id' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-default-filter-id-short-rental' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-default-filter-id-long-rental' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-default-filter-id-featured' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-default-filter-id-pdf' );
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-include-only-area');
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-list-type-filter');
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-include-search-in-property-details-page');
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-css-include-search-in-property-details-page');
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-field-id-page-shortlist');
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-field-id-page-result-search');
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-field-id-page-property-details');
		register_setting( 'rojuaala-settings-group-main', 'rojuaala-debug-mode' );
		

	}

	public function field_api_key_juaala_callback() {
		$setting = esc_attr( get_option( 'rojuaala-own-api-key' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-own-api-key' value='$setting' /> <a href='javascript:openApiAyuda(modalApiKeyJuaala);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
		
	}

	public function field_api_key_callback() {
		$setting = esc_attr( get_option( 'rojuaala-api-key' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-api-key' value='$setting' /> <a href='javascript:openApiAyuda(modalApiKey);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
		
	}

	public function field_client_id_callback() {
		$setting = esc_attr( get_option( 'rojuaala-client-id' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-client-id' value='$setting' /> <a href='javascript:openApiAyuda(modalIdCliente);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
	}

	public function field_default_filter_id_callback() {
		$setting = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-default-filter-id' value='$setting' /> <a href='javascript:openApiAyuda(modalFilterDefault);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
	}

	public function field_default_filter_id_short_callback() {
		$setting = esc_attr( get_option( 'rojuaala-default-filter-id-short-rental' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-default-filter-id-short-rental' value='$setting' /> <a href='javascript:openApiAyuda(modalFilterShortRental);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
	}

	public function field_default_filter_id_long_callback() {
		$setting = esc_attr( get_option( 'rojuaala-default-filter-id-long-rental' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-default-filter-id-long-rental' value='$setting' /> <a href='javascript:openApiAyuda(modalFilterLongRental);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
	}

	public function field_default_filter_id_features_callback() {
		$setting = esc_attr( get_option( 'rojuaala-default-filter-id-featured' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-default-filter-id-featured' value='$setting' /> <a href='javascript:openApiAyuda(modalFilterFeatured);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
	}

	public function field_pdf_filter_callback() {
		$setting = esc_attr( get_option( 'rojuaala-default-filter-id-pdf' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-default-filter-id-pdf' value='$setting' />";
	}

	public function field_include_only_areas_callback() {
		$setting =  get_option( 'rojuaala-include-only-area' );
		echo "<input type='checkbox' name='rojuaala-include-only-area' value='1' " . checked( $setting, 1,false ) . "/>";
	}

	public function field_list_type_filter_callback() {

		//llamada a la API para recuperar la lista de tipos de propiedades
		$setting =  get_option( 'rojuaala-list-type-filter' );
		$id_filter = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
		$rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
		$rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
		$lang_request = $this->get_locale_page_rso_juaala();
		$initParams = array(
			'P_ApiId' => $id_filter,
			'p1' => $rojuaala_client_id,
			'p2' => $rojuaala_api_key,
			'P_Lang' => $lang_request
		);
		$apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
		$responseTypes = $apiController->getRequest($initParams,'getPropertiesTypes');
		if (isset($responseTypes['PropertyTypes']) && isset($responseTypes['PropertyTypes']['PropertyType'])) {
			echo '<select  name="rojuaala-list-type-filter[]" id="search_types" multiple style="height:250px">';
				foreach($responseTypes['PropertyTypes']['PropertyType'] as $type) {
					echo '<option class="font-weight-bold" value="' . $type['OptionValue'] . '"' . (is_array($setting) ? selected( in_array(trim($type['OptionValue']),$setting), 1,false ) : '') . '><b>' .  $type['Type'] . '</b></option>';
					//si existe subtypes dividir
					$with_subtypes = false;
					if (isset($type['SubType']) && count($type['SubType'])>0) {
						$with_subtypes = true;
					}
				
					if ($with_subtypes) { 
						foreach($type['SubType'] as $subtype) { 
							echo '<option value="' . $subtype['OptionValue'] . '"' . (is_array($setting) ? selected(in_array(trim($subtype['OptionValue']),$setting), 1,false ) : ''). '>&nbsp;&nbsp;&nbsp;&nbsp;' . $subtype['Type'] . '</option>';
						}
					} 
				}
			echo "</select>";
		} else {
			echo "No properties types found";
		}
	}

	public function field_include_search_propery_details_page_callback() {
		$setting =  get_option( 'rojuaala-include-search-in-property-details-page' );
		$setting_css =   esc_attr(get_option( 'rojuaala-css-include-search-in-property-details-page'));
		
		echo "<input type='checkbox' name='rojuaala-include-search-in-property-details-page' value='1' " . checked( $setting, 1,false ) . "/>";
		echo "<div style='display:none'>CSS class: <input class='regular-text ' type='text' name='rojuaala-css-include-search-in-property-details-page' value='$setting_css' /></div>";
		
	}

	public function field_include_id_page_shortlist_callback() {
		$setting = esc_attr( get_option( 'rojuaala-field-id-page-shortlist' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-field-id-page-shortlist' value='$setting' />";
	}

	public function field_include_id_page_resultsearch_callback() {
		$setting = esc_attr( get_option( 'rojuaala-field-id-page-result-search' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-field-id-page-result-search' value='$setting' />";
	}

	public function field_include_id_page_property_details_callback() {
		$setting = esc_attr( get_option( 'rojuaala-field-id-page-property-details' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-field-id-page-property-details' value='$setting' />";
	}

	public function field_debug_mode_callback() {

		$setting = esc_attr( get_option( 'rojuaala-debug-mode' ) );
		if (!isset($setting) || $setting=='') {
			$setting = 0;
		}
		echo "<input class='regular-text' type='hidden' name='rojuaala-debug-mode' value='$setting' />";
		
	}

	public function field_css_text_callback() {

		$setting = esc_attr( get_option( 'rojuaala-css-text' ) );
		if (!isset($setting) || $setting=='') {
			$setting = '';
		}

		echo '<textarea id="rojuaala-css-text"  name="rojuaala-css-text">' . $setting . '</textarea>';
		
	}

	public function section_main_callback() {
		echo '';
	}

	/**Funciones para el tab de idioma */
	public function init_tab_idioma() {
		add_settings_section( 'section-language',  __('Language','rsonline-juaala'), array($this,'section_language_callback'), 'resalesonline_settings_page_language' );
		add_settings_field( 'field-default-lang', __('Default language','rsonline-juaala'), array($this,'field_map_default_lang_callback'), 'resalesonline_settings_page_language', 'section-language' );
		register_setting( 'rojuaala-settings-group-language', 'rojuaala-default-lang');
	}

	public function field_map_default_lang_callback() {
		$setting =   esc_attr(get_option( 'rojuaala-default-lang'));
		echo "<input class='regular-text' type='text' name='rojuaala-default-lang' value='$setting' />";
	}

	public function section_language_callback() {
		//echo 'Introduce el código del idioma por defecto a utilizar en las llamas a Resales Online <br><small>(es: español, en: inglés)</small> ';
	}

	/** FIN Funciones para el tab de idioma */

	/**Funciones para el tab de mapa */
	public function init_tab_map() {
		add_settings_section( 'section-map', '', array($this,'section_map_callback'), 'resalesonline_settings_page_map' );
		add_settings_field( 'field-map-property', __('Map integration Property','rsonline-juaala'), array($this,'field_map_integration_property_callback'), 'resalesonline_settings_page_map', 'section-map' );
		add_settings_field( 'field-map-api-key-google', __('Google Map api key','rsonline-juaala'), array($this,'field_map_api_key_google_map_callback'), 'resalesonline_settings_page_map', 'section-map' );
			
		register_setting( 'rojuaala-settings-group-map', 'rojuaala-map-integrarion-property');
		register_setting( 'rojuaala-settings-group-map', 'rojuaala-google-map-apikey');
	}

	public function field_map_integration_property_callback() {

		$setting = get_option( 'rojuaala-map-integrarion-property' );
		
		echo "<select style='width:100%' class='regular-text' name='rojuaala-map-integrarion-property'>
			<option value='0' " . selected( $setting, 0,false ) . ">OpenStreepMap</option>
			<option value='1' " . selected( $setting, 1,false ) . ">" . __('Google Map (Required Api key)','rsonline-juaala') . "</option>
		</select>";
		
	}

	public function field_map_api_key_google_map_callback() {
		$setting_api_key_google_map = esc_attr( get_option( 'rojuaala-google-map-apikey' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-google-map-apikey' value='$setting_api_key_google_map' />";
	}

	public function section_map_callback() {
		//echo 'Configuración de mapa';
	}

	/** FIN Funciones para el tab de mapa */

 	/**Funciones para el tab de form contact */
	 public function init_tab_contact() {
		add_settings_section( 'section-contact', '', array($this,'section_contact_callback'), 'resalesonline_settings_page_contact' );
		
		add_settings_field( 'field-three',  __('Id Contact Form 7 property','rsonline-juaala'), array($this,'field_contact_form_7_id_callback'), 'resalesonline_settings_page_contact', 'section-contact' );
		add_settings_field( 'field-wp-forms',  __('Id Contact WP Forms property','rsonline-juaala'), array($this,'field_contact_form_wp_forms_id_callback'), 'resalesonline_settings_page_contact', 'section-contact' );
		register_setting( 'rojuaala-settings-group-contact', 'rojuaala-id-contact-form-7-property' );
		register_setting( 'rojuaala-settings-group-contact', 'rojuaala-id-contact-wp-forms-property' );
	}

	public function section_contact_callback() {
		echo '';
	}

	public function field_contact_form_7_id_callback() {
		$setting = esc_attr( get_option( 'rojuaala-id-contact-form-7-property' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-id-contact-form-7-property' value='$setting' /> <a href='javascript:openApiAyudaContact(modalContacForm7);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
	}

	public function field_contact_form_wp_forms_id_callback() {
		$setting = esc_attr( get_option( 'rojuaala-id-contact-wp-forms-property' ) );
		echo "<input class='regular-text' type='text' name='rojuaala-id-contact-wp-forms-property' value='$setting' /> <a href='javascript:openApiAyudaContact(modalWpForms);'><i class='fas fa-question-circle' aria-hidden='true'></i></a>";
	}


	/** FIN Funciones para el form contact */

	/**Funciones para el tab de pdf */
	public function init_tab_pdf() {
		add_settings_section( 'section-pdf', __('PDF generation','rsonline-juaala'), array($this,'section_pdf_callback'), 'resalesonline_settings_page_pdf' );
		add_settings_field( 'field-nine', __('Imagen header','rsonline-juaala'), array($this,'field_slug_image_upload'),'resalesonline_settings_page_pdf', 'section-pdf' );
		add_settings_field( 'field-eight', __('Info header','rsonline-juaala'), array($this,'field_info_contact_pdf_callback'), 'resalesonline_settings_page_pdf', 'section-pdf' );
		add_settings_field( 'field-thirteen', __('Text Footer','rsonline-juaala'), array($this,'field_info_contact_footer_pdf_callback'), 'resalesonline_settings_page_pdf', 'section-pdf' );
		register_setting( 'rojuaala-settings-group-pdf', 'rojuaala-text-contact-pdf' );
		register_setting( 'rojuaala-settings-group-pdf', 'rojuaala-text-footer-pdf' );
		register_setting( 'rojuaala-settings-group-pdf', 'rojuaala-image-pdf');
		
	}

	public function section_pdf_callback() {
		echo '';
	}

	public function field_slug_image_upload() {
		$option_src_image = get_option('rojuaala-image-pdf');
		if ( $option_src_image!='') {
			echo "<img src='$option_src_image' alt='' style='width:150px'><br>";
		}
		echo '<label for="upload_image">
				<input id="upload_image_pdf" type="text" size="36" name="rojuaala-image-pdf" value="' . $option_src_image . '" /> 
				<input id="upload_image_pdf_button" class="button" type="button" value="' . __('Upload Image','rsonline-juaala') . '" />
				<br />' . __('Enter a URL or upload an image','rsonline-juaala') . '
			</label>';
	}

	public function field_info_contact_pdf_callback() {
		$setting = esc_attr( get_option( 'rojuaala-text-contact-pdf' ) );
		$setting = html_entity_decode($setting);
		$setting = stripslashes($setting);
		$editor_id = 'rojuaala-text-contact-pdf';
		$config  = array( 'media_buttons' => false, 'textarea_name' => 'rojuaala-text-contact-pdf' );		
		wp_editor( html_entity_decode($setting), $editor_id, $config );
	}

	public function field_info_contact_footer_pdf_callback() {
		$setting = esc_attr( get_option( 'rojuaala-text-footer-pdf' ) );
		$setting = html_entity_decode($setting);
		$setting = stripslashes($setting);
		$editor_id = 'rojuaala-text-footer-pdf';
		$config  = array( 'media_buttons' => false, 'textarea_name' => 'rojuaala-text-footer-pdf' );
		wp_editor( html_entity_decode($setting), $editor_id, $config );
	}


  /** FIN Funciones para el tab de pdf */

	/**Funciones para el tab de styles */
	public function init_tab_styles() {
		add_settings_section( 'section-styles', '', array($this,'section_styles_callback'), 'resalesonline_settings_page_styles' );
		add_settings_field( 'field-primary-color', __("Primary color",'rsonline-juaala'), array($this,'field_primary_color_callback'), 'resalesonline_settings_page_styles', 'section-styles' );
		register_setting( 'rojuaala-settings-group-styles', 'rojuaala_primary_color');
		add_settings_field( 'field-css-text-rsonline-juaala', __("Custom CSS",'rsonline-juaala'), array($this,'field_css_text_callback'), 'resalesonline_settings_page_styles', 'section-styles' );
		register_setting( 'rojuaala-settings-group-styles', 'rojuaala-css-text' );

	}

	public function section_styles_callback() {
		echo '';
	}

	public function field_primary_color_callback() {
		$setting = esc_attr( get_option( 'rojuaala_primary_color' ) );
		if (empty($setting)) {
			$setting = "#000";
		}
		echo "<input class='regular-text' type='text' name='rojuaala_primary_color' value='$setting' />";
	}


	protected function get_locale_page_rso_juaala() {
		$lang_request = 1; //POR DEFECTO INGLÈS
		if (defined('ICL_LANGUAGE_CODE')) {
			if (isset(LANG_RS_ONLINE[ICL_LANGUAGE_CODE])) {
				$lang_request = LANG_RS_ONLINE[ICL_LANGUAGE_CODE];
			}
		}
		else if (function_exists('pll_current_language'))  {
			$lang = pll_current_language();
			if (isset(LANG_RS_ONLINE[$lang])) {
				$lang_request = LANG_RS_ONLINE[$lang];
			}
		}  else {
			//idioma de la instalacion de wordpress
			$lang_wordpress = get_locale();
			if ($lang_wordpress) {
				$lang = substr($lang_wordpress, 0, 2);
				if (isset(LANG_RS_ONLINE[$lang])) {
					$lang_request = LANG_RS_ONLINE[$lang];
				}
			} else {
				//idioma del navegador
				substr($_SERVER['HTTP_ACCEPT_LANGUAGE'], 0, 2);
				$lang = substr($_SERVER['HTTP_ACCEPT_LANGUAGE'], 0, 2);
				if (isset(LANG_RS_ONLINE[$lang])) {
					$lang_request = LANG_RS_ONLINE[$lang];
				}
			}
		}
		return $lang_request;
	}

public function rojuaala_primary_color_save( $new_value, $old_value ) {
		$this->update_scss($new_value, $old_value);
		if ($old_value !=$new_value) {
			//actualizar el fichero scss con el nuevo valor del valor primario
		}
		return $new_value;
}

protected function update_scss($new_value, $old_value) {
	//ruta del fichero
	$real = dirname(__FILE__).'/../public/assets/scss/scss/_bootstrap_variables.scss'; 
	$str= file_get_contents($real);
	$str=str_replace($old_value, $new_value,$str);
	file_put_contents($real, $str);
}

public function get_doc() {

	try {
	
		$id = $_GET['params']['id'];
		$lang_request = $this->get_locale_page_rso_juaala();
	
		$templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
		
		$html = $templatesController->get_doc($id,$lang_request);
	
		$html = "" . $html;
		
		$return = array(
			'html'  => $html,
		);
		wp_send_json_success($return);
	} catch(Exception $e) {
		$return = array(
			'html'  => "Error al recuperar la documentación",
		);
		wp_send_json_success($return);
	}

}

/**
 * This function runs when WordPress completes its upgrade process
 * It iterates through each plugin updated to see if ours is included
 * @param $upgrader_object Array
 * @param $options Array
 */
function juaala_wp_upe_upgrade_completed( $upgrader_object, $options ) {
	// If an update has taken place and the updated type is plugins and the plugins element exists
	if( $options['action'] == 'update' && $options['type'] == 'plugin' && isset( $options['plugins'] ) ) {
	 // Iterate through the plugins being updated and check if ours is there
	 foreach( $options['plugins'] as $plugin ) {
		if( $plugin == $this->file_plugin ) {
			// Set a transient to record that our plugin has just been updated
			$new_value = esc_attr( get_option( 'rojuaala_primary_color' ) ); //valor del introducido por el usuario
			if (!isset($new_value) || $new_value=='' ) {
				$new_value = '#000';
			}
			$old_value = '#000'; //valor por defecto al descargar el fichero
			$this->update_scss($new_value, $old_value);
			//añadimos la página de compare si no existiese. A partir de la versión 1.0.9
			$content_f = get_post(15335);
			if (!$content_f) {
				$shortcode_compare = "juaala_rso_compare";
				// Crear página de comparacion
				$my_post_compare = array(
					'import_id'         =>  15335,
					'post_title'    => wp_strip_all_tags( __('Comparison list','rsonline-juaala') ),
					'post_content'  => '['.$shortcode_compare.'/]',
					'post_status'   => 'publish',
					'post_author'   => get_current_user_id(),
					'post_type'     => 'page',
				);
				wp_insert_post( $my_post_compare );
			}			
		}
	 }
	}
}

function juaala_rso_pdf_geretaror_job (
		$references='',
		$filter_id='',
		$lang='', 
		$template='',
		$path='',
		$image_url='',
		$text_header='',
		$text_footer='',
		$api_key_resales='', 
		$api_key_juaala='',
		$id_client='',
		$number=40,
		$sort=3,
		$size='A4',
		$orientation='landscape',
		$resolution=96,
		$zip=true,
		$alternative_lang=''
		) {

		
		if ($api_key_resales=='') {
			$api_key_resales  = esc_attr( get_option( 'rojuaala-api-key' ) );
		}
		if ($api_key_juaala=='') {
			$api_key_juaala  = esc_attr( get_option( 'rojuaala-api-key' ) );
		}

		if ($id_client=='') {
			$id_client  =  esc_attr( get_option( 'rojuaala-client-id' ) );
		}

		if ($filter_id=='') {
			$filter_id  = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
		}

		if ($lang=='') {
			$lang_request = $this->get_locale_page_rso_juaala();
		} else {
			$lang_request = $lang;
		}

		if ($path!='') {
			$path_export = $path;
		}else {
			if (defined('EXPORT_PATH_SCREEN')) {
				$path_export = EXPORT_PATH_SCREEN;
			} else {
				$path_export = 'exports';
			}
		} 


		$initParams = array(
			'P_ApiId' => $filter_id,
			'p1' => $id_client,
			'p2' => $api_key_resales,
			'P_Lang' => $lang_request,
			'p_PageSize' => $number,
			'P_SortType' => $sort
		);

		$apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
			
		$properties = [];

		if ($references=='') {
			
			$response = $apiController->getRequest($initParams,'getProperties');
			if ($response && $response['QueryInfo'] && $response['QueryInfo']['PropertyCount']) {
				$properties_export_pdf = $response['Property'];
				foreach($properties_export_pdf as $property) {
					if (count($property['Pictures']['Picture'])!=0) {

						$initParamsProperty = array(
							'P_ApiId' => $filter_id,
							'p1' => $id_client,
							'p2' => $api_key_resales,
							'P_Lang' => $lang_request,
							'P_RefId' => $property['Reference'],
						
						);
						//llamamos al detalle de propiedad para incluir la imagen de del certificado energetico (si la tuvise) y gastos de impuestos (En el listado no vienen esos datos)
						$apiControllerProperty = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
						$responseProperty = $apiControllerProperty->getRequest($initParamsProperty,'getProperty');
						if (isset($responseProperty['Property'])) {
							$properties[] =$responseProperty['Property'];
						}
					}
				}
			}
		} else {
			$references_array = explode(",", $references);
			foreach($references_array as $ref) {
				if ($ref!='') {
					$initParamsProperty = array(
						'P_ApiId' => $filter_id,
						'p1' => $id_client,
						'p2' => $api_key_resales,
						'P_Lang' => $lang_request,
						'P_RefId' => $ref,
					);
					$apiControllerProperty = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
					$responseProperty = $apiControllerProperty->getRequest($initParamsProperty,'getProperty');
					if (isset($responseProperty['Property'])) {
						if (count($responseProperty['Property']['Pictures']['Picture'])!=0) {
							$properties[] = $responseProperty['Property'];
						}
					}
				}
			}
		}

		if (isset($properties) && count($properties)>0) {

			//eliminados todos los jpg y todos los pdf anteriores
			$fullPath = ABSPATH . $path_export . "/" ;
			if (!is_dir($fullPath)) {
				mkdir($fullPath);
			}
			
			array_map('unlink', glob( "$fullPath*.jpg"));
			array_map('unlink', glob( "$fullPath*.pdf"));
			array_map('unlink', glob( "$fullPath*.zip"));

			foreach($properties as $property) {
				$propertyAltLang=null;
					//solo si tiene imagen
				if (count($property['Pictures']['Picture'])!=0) {
					if ($alternative_lang!='') {
						//buscamos la propiedad con lengua alternativa
						$initParams_alternative_lang = array(
							'P_ApiId' => $filter_id,
							'p1' => $id_client,
							'p2' => $api_key_resales,
							'P_Lang' => $alternative_lang,
							'P_RefId' => $property['Reference'],
						);
						$apiControllerAlternativeLang = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
						$responseAlt = $apiControllerAlternativeLang->getRequest($initParams_alternative_lang,'getProperty');
						if (isset($responseAlt['Property'])) {
							$propertyAltLang = $responseAlt['Property'];
						}
					}

					$templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES,'PUT', $api_key_juaala);
					$rs_juaala_pdf_request = new stdClass();
					$rs_juaala_pdf_request->property=$property;
					$rs_juaala_pdf_request->propertyAlt=$propertyAltLang;
					$rs_juaala_pdf_request->template=$template;
					$image_src_pdf = '';
					if ($image_url!='') {
						$image_src_pdf = $image_url;
					} else {
						if ( get_option('rojuaala-image-pdf')=='') {
							$image = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );
							$image_src_pdf = $image[0];
						} else {
							$image_src_pdf = get_option('rojuaala-image-pdf');
						}
					}

					$rs_juaala_pdf_request->image_src_pdf = $image_src_pdf;
					$rs_juaala_pdf_request->text_contact_pdf = $text_header !='' ? $text_header : get_option( 'rojuaala-text-contact-pdf' );
					$rs_juaala_pdf_request->text_footer_pdf =  $text_footer !='' ? $text_footer : get_option( 'rojuaala-text-footer-pdf' );
					$rs_juaala_pdf_request->P_Lang = $lang_request;
					$pdf_string_html = $templatesController->getTemplate($rs_juaala_pdf_request, 'getTemplatePdfScreen');
					try {

						$dompdf = new Dompdf\Dompdf();
						$dompdf->set_option('isRemoteEnabled', TRUE);
						$size_convert = explode(",", $size);
						if (count($size_convert)==1) {
							$size_convert = $size;
						}
						$dompdf->setPaper($size_convert, $orientation);
						$dompdf->load_html($pdf_string_html);
						$dompdf->render();
						$output = $dompdf->output();
						$absolute_path = $fullPath . "property_" . $property['Reference'] . ".pdf";
						file_put_contents($absolute_path, $output);
						//Exportar a jpg
						$error_imagick = false;
						if (extension_loaded('imagick') ) {
							try {
								$imagick = new Imagick();
								$imagick->setResolution($resolution, $resolution);
								$imagick->setBackgroundColor('white');
								$imagick->readImage($absolute_path);
								$imagick = $imagick->flattenImages();
								$imagick->setImageFormat('jpg');
								$image_abosolute_path = str_replace("pdf", "jpg",$absolute_path);
								$imagick->writeImages($image_abosolute_path, false); 
							} catch(Exception $error_i) {
								$error_imagick = true;
							}
						} 
							
						if (!extension_loaded('imagick') || $error_imagick) {
							//no está la extensión imagick en el servidor del hosting o se produjo un error, probamos la opción remota
							try {
								$image_abosolute_path = str_replace("pdf", "jpg",$absolute_path);
								//generamos la imagen en el server enviando el pdf, descargar y guargar en la ruta
								$rs_juaala_pdf_convert_img = [];
								$rs_juaala_pdf_convert_img['name'] = 'pdf-file';
								$rs_juaala_pdf_convert_img['path'] = $absolute_path;
								$rs_juaala_pdf_convert_img['params'] = [
									"resolution" => $resolution
								];
								$image = $templatesController->sendFile($rs_juaala_pdf_convert_img, 'generateImageFromPdf','POST');
								file_put_contents($image_abosolute_path, $image);
							} catch(Exception $ee) {
								print_r($ee);
							}
						}
					} catch(Exception $e) {
						print_r($e);
					}
					
				}
			}

			//comprimir archivos
			if (class_exists('ZipArchive') && $zip) {
				//$pathdir = ABSPATH . "/" . $path_export;  

				$sufijo_file = date("Ymd"); 
				// Enter the name to creating zipped directory 
				$zipcreatedpdf =  $fullPath . "properties_pdf_" . $sufijo_file . ".zip"; 
				// Enter the name to creating zipped directory 
				$zipcreatedjpg =  $fullPath . "properties_jpg_" . $sufijo_file . ".zip"; 
					
				// Create new zip class 
				$zipPdf = new ZipArchive; 
				$zipJpg = new ZipArchive; 
		
					
				if($zipPdf->open($zipcreatedpdf, ZipArchive::CREATE ) === TRUE) { 
							
						// Store the path into the variable 
						$dir = opendir($fullPath); 
							
						while($file = readdir($dir)) { 
								if(is_file($fullPath.$file)) { 
									$partes_ruta = pathinfo($fullPath.$file);
									if ($partes_ruta['extension']=='pdf') {
										$zipPdf->addFile($fullPath.$file, $file); 
									}
								} 
						} 
						$zipPdf->close(); 
				} 

				if($zipJpg->open($zipcreatedjpg, ZipArchive::CREATE ) === TRUE) { 
							
					// Store the path into the variable 
					$dir = opendir($fullPath); 
						
					while($file = readdir($dir)) { 
							if(is_file($fullPath.$file)) { 
									$partes_ruta = pathinfo($fullPath.$file);
									if ($partes_ruta['extension']=='jpg') {
										$zipJpg->addFile($fullPath.$file, $file); 
									}
							} 
					} 
					$zipJpg->close(); 
				} 

				//enviar email notificando al usuario que tiene archivos zip con las propiedades
				$url_site = get_site_url();
				$urlPdf = $url_site . "/" . $path_export . "/properties_pdf_" . $sufijo_file . ".zip";
				$urlJpg = $url_site . "/" . $path_export . "/properties_jpg_" . $sufijo_file . ".zip";
				$email_admin = get_option('admin_email');
				$to = $email_admin;
				$subject = 'Se han generado nuevos documentos PDF y JPG de propiedades';
				$body = 'Hola, <br><br> Te adjuntamos los links para que puedas descargar los ficheros comprimidos que contienen los PDF y JPG de las propiedades para mostrar en las pantallas del escaparate.<br><br>
					PDF: <a href="' . $urlPdf . '">Descargar Fichero ZIP con PDF</a><br>
					JPG: <a href="' . $urlJpg .'">Descargar Fichero ZIP con JPG</a><br><br>

					Igualmente puedes ver el carrusel de propiedades accediendo a la página creada para ello.<br><br>

					Saludos,

				';
				$headers = array('Content-Type: text/html; charset=UTF-8');

				wp_mail( $to, $subject, $body, $headers );
			}
		}


	}
}
