<?php


class Rsonline_Juaala_Template_Controller
{

  protected $URL; 
  protected $endPoints; 
  public $version;

  function __construct($URL,$endPoints) {
    $this->URL = $URL;
    $this->endPoints = $endPoints;
    if ( defined( 'RSONLINE_JUAALA_VERSION' ) ) {
      $this->version = RSONLINE_JUAALA_VERSION;
    } else {
      $this->version = '1.0.0';
    }
  }

  public function sendFile($params, $end_point, $call="POST", $api_key='') {
      $responseString = '';
      try {
        if ($api_key=='') {
          $api_key = esc_attr( get_option( 'rojuaala-own-api-key' ) );
        }
        $client = new \GuzzleHttp\Client();
        $url = $this->URL . $this->endPoints[$end_point];
        $request = new \GuzzleHttp\Psr7\Request($call, $url, [
          'stream' => true,
          'forward_headers' => true,
          'connect_timeout' => CONNECT_TIMEOUT_GUZZLEHTTP,
          'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
        ]); 
        $promise = $client->sendAsync($request, [
          'stream' => true,
          'multipart' => [
            [
                'name'     => $params['name'],
                'contents' => fopen($params['path'], 'r')
            ],
            [
              'name'     => 'resolution',
              'contents' => $params['params']['resolution']
            ],
            [
              'name'     => 'version',
              'contents' => $this->version
            ]
          ],
          'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
        ])->then(function ($response) {
          
            global $responseString;
            $responseString = $response->getBody();
            $body = $response->getBody()->getContents();
            $responseString = $body;
            return $responseString;
        });
        $responseString = $promise->wait();
      } catch (\GuzzleHttp\Exception\RequestException $ex) {
        $debug_mode = esc_attr( get_option( 'rojuaala-debug-mode' ) );
        if (isset($debug_mode) && $debug_mode=='1') {
          try {
            echo "<pre>";
            echo $ex->hasResponse();
            print_r($ex->getResponse()->getBody()->getContents());
            echo "</pre>";
          } catch(\Exception $e) {
            echo $e->getMessage();
          }
        } else {
          global $responseString;
          $responseString = "<p style='text-align:center;margin: 16px'>Error al generar imagen desde PDF</p>";
        }
      }
      return $responseString;
  }

  public function getTemplate($params,$end_point, $call="PUT",$api_key='') {
    $responseString = '';
    try {
      $client = new \GuzzleHttp\Client();
      $url = $this->URL . $this->endPoints[$end_point];
      $params->version = $this->version;
     
      $css_text = esc_attr( get_option( 'rojuaala-css-text' ) );
      if (isset($css_text) && $css_text!='') {
        $params->css_text = $css_text;
      }
      
      $params_form = json_encode($params,JSON_FORCE_OBJECT);
      $compressed = gzdeflate($params_form,9);
      if ($api_key=='') {
        $api_key = esc_attr( get_option( 'rojuaala-own-api-key' ) );
      }

      $request = new \GuzzleHttp\Psr7\Request($call, $url, [
        'forward_headers' => true,
        'connect_timeout' => CONNECT_TIMEOUT_GUZZLEHTTP,
        'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
      ]); 
      $promise = $client->sendAsync($request,[
        'body' => $compressed,
        'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
      ])->then(function ($response) {
          global $responseString;
          $responseString = $response->getBody();
          return $responseString;
      });
      $responseString = $promise->wait();
    } catch (\GuzzleHttp\Exception\RequestException $ex) {
      $debug_mode = esc_attr( get_option( 'rojuaala-debug-mode' ) );
        if (isset($debug_mode) && $debug_mode=='1') {
          try {
            echo "<pre>";
            echo $ex->hasResponse();
            print_r($ex->getResponse()->getBody()->getContents());
            echo "</pre>";
          } catch(\Exception $e) {
            echo $e->getMessage();
          }
        } else {
          global $responseString;
          $responseString = "<p style='text-align:center;margin: 16px'>Error</p>";
        }
    }

    $debug_mode = esc_attr( get_option( 'rojuaala-debug-mode' ) );
    if (isset($debug_mode) && $debug_mode=='1') {

      $id_debug = str_shuffle('mnopqrstuvwxyz');

      echo "<div style=''>";
      echo '<button class="btn btn-primary" type="button" data-bs-toggle="collapse" data-bs-target="#' .$id_debug .'" aria-expanded="false" aria-controls="'. $id_debug . '">Request API TEMPLATE JUAALA - ' . $end_point .'</button>';
      echo '<div class="collapse multi-collapse" id="' . $id_debug .'">
            <div class="card card-body">';
      echo "<div>End point: " . $end_point . "</div>"; 
      echo '<div>Params request:</div>';
      echo "<pre>";
            print_r($params);
      echo "</pre>";
      echo '<div>Return:</div>';
      echo "<pre>";
            print_r($responseString);
      echo "</pre></div></div>";

   }
    return $responseString;

  }

  public function getApikey() {
    $responseString = '';
    try {
      $client = new \GuzzleHttp\Client();
      $url = $this->URL . $this->endPoints['getTemplateApiKey'];
      $api_key = esc_attr( get_option( 'rojuaala-own-api-key' ) );
      
      $request = new \GuzzleHttp\Psr7\Request('GET', $url, [
        'connect_timeout' => CONNECT_TIMEOUT_GUZZLEHTTP,
        'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
      ]);
      $promise = $client->sendAsync($request,[
        'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
      ])->then(function ($response) {
          
          global $responseString;
          $responseString = $response->getBody();
          $responseString = json_decode($responseString, true);
          return $responseString;
      });
      $responseString = $promise->wait();
    } catch (\GuzzleHttp\Exception\RequestException $ex) {
      global $responseString;
      $responseString = "Error";
    }
    return $responseString;
  }

  public function get_doc($id,$lang) {
    $responseString = '';
    try {
      $client = new \GuzzleHttp\Client();
      $url = $this->URL . $this->endPoints['getTemplateDoc'] . "?id=$id&lang=" . $lang;
      $api_key = esc_attr( get_option( 'rojuaala-own-api-key' ) );
      
      $request = new \GuzzleHttp\Psr7\Request('GET', $url, [
        'connect_timeout' => CONNECT_TIMEOUT_GUZZLEHTTP,
        'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
      ]);
      $promise = $client->sendAsync($request,[
        'headers'        => ['X-Header-Juaala-APIKEY' => $api_key, 'X-Header-Juaala-Domain' => $_SERVER['SERVER_NAME']]
      ])->then(function ($response) {
          global $responseString;
          $responseString = $response->getBody();
          return $responseString;
      });
      $responseString = $promise->wait();
      return $responseString;
    } catch (\GuzzleHttp\Exception\RequestException $ex) {
      global $responseString;
      $responseString = "Error al recuperar la documentación";
      return $responseString;
    }
    
  }
}