<?php
/**
 * Updates from a custom server
 *
 * @link       https://juaala.com/
 * @since      1.0.0
 *
 * @package    Rsonline_Juaala
 * @subpackage Rsonline_Juaala/includes
 * @author     Juaala <info@juaala.com>
 */

defined( 'ABSPATH' ) || exit;


if( ! class_exists( 'juaalaRSOUpdateChecker' ) ) {

	class juaalaRSOUpdateChecker{

		public $plugin_slug;
		public $version;
		public $cache_key;
		public $cache_allowed;

		public function __construct() {

			$this->plugin_slug = 'rsonline-juaala';
		
			if ( defined( 'RSONLINE_JUAALA_VERSION' ) ) {
				$this->version = RSONLINE_JUAALA_VERSION;
			} else {
				$this->version = '1.0.0';
			}
			$this->cache_key = 'juaala_custom_upd';
			$this->cache_allowed = false;

			add_filter('plugin_row_meta', array( $this, 'juaala_meta_links') , 11, 2);
			add_filter( 'plugins_api', array( $this, 'info' ), 10, 3 );
			add_filter( 'site_transient_update_plugins', array( $this, 'update' ) );
			add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );

			/** ========================================================
			 * FILTERS
			* =====================================================  */
			add_filter('plugin_action_links', array( $this, 'juaala_manage_link'), 10, 2);
	

		}

		public function request(){

			$remote = get_transient( $this->cache_key );

			if( false === $remote || ! $this->cache_allowed ) {

				$remote = wp_remote_get(
					'https://resalesonline.juaala.com/updater/info.json',
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);

				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					return false;
				}

				set_transient( $this->cache_key, $remote, DAY_IN_SECONDS );

			}
			

			$remote = json_decode( wp_remote_retrieve_body( $remote ) );

			return $remote;

		}


		public function info( $res, $action, $args ) {




			// do nothing if you're not getting plugin information right now
			if( 'plugin_information' !== $action ) {
				return $res;
			}

			// do nothing if it is not our plugin
			if( $this->plugin_slug !== $args->slug ) {
				return $res;
			}

			// get updates
			$remote = $this->request();

			if( ! $remote ) {
				return $res;
			}

			$res = new stdClass();
			//comprobar si tiene ti
			//$templatesController = new ResalesOnlineApi\Templates(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      //$apikey_response = $templatesController->getApiKey();
			$res->name = $remote->name;
			$res->slug = $remote->slug;
			$res->version = $remote->version;
			$res->tested = $remote->tested;
			$res->requires = $remote->requires;
			$res->author = $remote->author;
			$res->author_profile = $remote->author_profile;
			$res->download_link = $remote->download_url;
			$res->trunk = $remote->download_url;
			$res->requires_php = $remote->requires_php;
			$res->last_updated = $remote->last_updated;

			$res->sections = array(
				'description' => $remote->sections->description,
				'installation' => $remote->sections->installation,
				'changelog' => $remote->sections->changelog
			);

			if( ! empty( $remote->banners ) ) {
				$res->banners = array(
					'low' => $remote->banners->low,
					'high' => $remote->banners->high
				);
			}

			return $res;

		}

		public function update( $transient ) {
		

			if ( empty($transient->checked ) ) {
				return $transient;
			}

			$remote = $this->request();

		

			if(
				$remote
				&& version_compare( $this->version, $remote->version, '<' )
				&& version_compare( $remote->requires, get_bloginfo( 'version' ), '<' )
				&& version_compare( $remote->requires_php, PHP_VERSION, '<' )
			) {
				
				$res = new stdClass();
				$res->slug = $this->plugin_slug;
				$res->plugin = 'rsonline-juaala/rsonline-juaala.php';// plugin_basename( __FILE__ ); // misha-update-plugin/misha-update-plugin.php
				$res->new_version = $remote->version;
				$res->tested = $remote->tested;
				$res->package = $remote->download_url;

				$transient->response[ $res->plugin ] = $res;
			
	    }
			
			return $transient;

		}

		public function purge(){

			if (
				$this->cache_allowed
				&& 'update' === $options['action']
				&& 'plugin' === $options[ 'type' ]
			) {
				// just clean the cache when new plugin version is installed
				delete_transient( $this->cache_key );
			}

		}

		/**
		 * Adds the manage link in the plugins list 
     *
     * @access global
     * @return string The manage link in the plugins list 
     */	
    public function juaala_manage_link($links, $file) 
			{
				static $this_plugin;
				
				if (!$this_plugin)
						$this_plugin = plugin_basename('rsonline-juaala/rsonline-juaala.php');

					
				if ($file == $this_plugin) {
						/*
						$settings_link = '<a href="admin.php??page=juaala-rso-settings-page">' . esc_html__("Ajustes", 'rsonline-juaala') . '</a>';
						array_unshift($links, $settings_link);
						*/
						$templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
						$apiKeyStatus = $templatesController->getApikey();
						if ($apiKeyStatus['created']==1 && $apiKeyStatus['demo']==1) {
							$upgrade_link = '<a href="' . $apiKeyStatus['url'] . '" target="_blank"><strong style="color: #b20000; display: inline;">' . esc_html__("Renovar ApiKey", 'rsonline-juaala') . '</strong></a>';
							array_unshift($links, $upgrade_link);
						} else if ($apiKeyStatus['created']==0) {
							$upgrade_link = '<a href="' . $apiKeyStatus['url'] .'" target="_blank"><strong style="color: #11967A; display: inline;">' . esc_html__("Obtener ApiKey", 'rsonline-juaala') . '</strong></a>';
							array_unshift($links, $upgrade_link);	
						} else if ($apiKeyStatus['created']==1 && $apiKeyStatus['demo']==0) {
							$upgrade_link = '<strong style="color: #80b900; display: inline;">' . esc_html__("ApiKey válida", 'rsonline-juaala') . '</strong>';
							array_unshift($links, $upgrade_link);	
						}
						
						
				}
				return $links;
			}

		/**
		 * Adds links to the plugins manager page
     *
     * @access global
     * @return string The meta help link data for the plugins manager
     */
    function juaala_meta_links($links, $file) 
			{
        $plugin = plugin_basename('rsonline-juaala/rsonline-juaala.php');
        // create link
        if ($file == $plugin) {
            $links[] = '<a href="admin.php?page=juaala-rso-settings-page" title="' . esc_attr__('Ajustes', 'rsonline-juaala') . '" style="">' . esc_html__('Ajustes', 'rsonline-juaala') . '</a>';
            return $links;
        }
        return $links;
    	}

		}

	new juaalaRSOUpdateChecker();

}
