<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://juaala.com/
 * @since      1.0.0
 *
 * @package    Rsonline_Juaala
 * @subpackage Rsonline_Juaala/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Rsonline_Juaala
 * @subpackage Rsonline_Juaala/public
 * @author     Juaala <info@juaala.com>
 */
class Rsonline_Juaala_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Rsonline_Juaala_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Rsonline_Juaala_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/rsonline-juaala-public.css', array(), $this->version, 'all' );
    $number_version = intval(str_replace(".", "", $this->version));
		if ($number_version<=104) {
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'assets/scss/style.php?p=rs_juaala.scss', array(), null, 'all');
		} else {
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'assets/scss/style.php?p=rs_juaalav2.scss', array(), null, 'all');
		}	
		wp_enqueue_style('fontawesome', plugin_dir_url( __FILE__ ) . 'assets/fontawesome/css/all.min.css', array(),  $this->version, 'all');
		wp_enqueue_style($this->plugin_name . '-leaflet', plugin_dir_url ( __FILE__ ) . 'assets/vendor/leaflet/leaflet.css', array(), $this->version,  'all');

    wp_enqueue_style($this->plugin_name . '-lightgallery-bundle', plugin_dir_url ( __FILE__ ) . 'assets/vendor/lightGallery/dist/css/lightgallery-bundle.css', array(), $this->version,  'all');

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Rsonline_Juaala_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Rsonline_Juaala_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */


    $number_version = intval(str_replace(".", "", $this->version));
    if ($number_version<=104) {
      wp_enqueue_script($this->plugin_name . '-js-bootstrap', plugin_dir_url ( __FILE__ ) . 'assets/vendor/bootstrap-5.0.2/dist/js/bootstrap.bundle.min.js', array('jquery'), $this->version, false);
    } else {
      wp_enqueue_script($this->plugin_name . '-js-bootstrap', plugin_dir_url ( __FILE__ ) . 'assets/vendor/bootstrap-5.2.3/dist/js/bootstrap.bundle.min.js', array('jquery'), $this->version, false);
    }
    
    wp_enqueue_script($this->plugin_name . '-js-popper', plugin_dir_url ( __FILE__ ) . 'assets/vendor/popper.min.js', array(), $this->version, false);
		wp_enqueue_script($this->plugin_name . '-js-bootstrap-select', plugin_dir_url (__FILE__) . 'assets/vendor/bootstrap-select-1.14.0-beta3/js/bootstrap-select.js', array('jquery', $this->plugin_name . '-js-bootstrap',$this->plugin_name . '-js-popper'), $this->version, false);

		wp_enqueue_script($this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/rsonline-juaala-public.js', array( 'jquery' ), $this->version, false );
		wp_localize_script($this->plugin_name, 'wp_ajax_vars', array(
			'ajax_url' => admin_url( 'admin-ajax.php' )
		));

		wp_enqueue_script($this->plugin_name . 'js-leaflet', plugin_dir_url ( __FILE__ ) . 'assets/vendor/leaflet/leaflet.js', array(), $this->version, false);
		wp_enqueue_script($this->plugin_name . 'js-leaflet-geosearch', plugin_dir_url ( __FILE__ ) . 'assets/vendor/leaflet/leaflet-geosearch.min.js', array(), $this->version, false);

    //lightGallery
    wp_enqueue_script($this->plugin_name . 'js-lightgallery-umd', plugin_dir_url ( __FILE__ ) . 'assets/vendor/lightGallery/dist/lightgallery.umd.js', array(), $this->version, false);
    wp_enqueue_script($this->plugin_name . 'js-thumbnail-umd', plugin_dir_url ( __FILE__ ) . 'assets/vendor/lightGallery/dist/plugins/thumbnail/lg-thumbnail.min.js', array(), $this->version, false);
    wp_enqueue_script($this->plugin_name . 'js-lg-zoom-umd', plugin_dir_url ( __FILE__ ) . 'assets/vendor/lightGallery/dist/plugins/zoom/lg-zoom.min.js', array(), $this->version, false);
    wp_enqueue_script($this->plugin_name . 'js-lg-fullscreen-umd', plugin_dir_url ( __FILE__ ) . 'assets/vendor/lightGallery/dist/plugins/fullscreen/lg-fullscreen.min.js', array(), $this->version, false);
	}

	function juaala_rso_search_shortcode( $atts ) {


		if (empty($atts)) {
      $atts=[];
    }
  
    $rs_juaala_search_form = new stdClass();
    $is_form_rental = false;
    if (isset($atts['is_form_rental'])) {
      $is_form_rental = $atts['is_form_rental'];
      $rs_juaala_search_form->is_form_rental = $atts['is_form_rental'];
    }

    if (!isset($atts['filter_id'])) {
      //cogemos por defecto el configurado
      if (!$is_form_rental) {
        $atts['filter_id']  = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
      } else if ($is_form_rental=="short") {
        $atts['filter_id']  = esc_attr( get_option( 'rojuaala-default-filter-id-short-rental' ) );
      } else if ($is_form_rental=="long") {
        $atts['filter_id']  = esc_attr( get_option( 'rojuaala-default-filter-id-long-rental' ) );
      }
    } 

    //otros atributos pasados por parametro
    $others_params = [];
    $no_include_others_params = array(
                'filter_id',
                'class',
                'results_own_page',
                'class_collapse',
                'collapse',
                'state_collapse',
                'include_title_page',
                'is_form_rental',
                'number_properties'
              );
    foreach ($atts as $key => $value) {
      if (!in_array($key, $no_include_others_params)) {
        $others_params[$key] = $value;
      }
    }
    //comprobar que esté instalado polylang para ver que idioma es que hay que mandar
    $lang_request = $this->get_locale_page_rso_juaala();

    $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
    $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
    $all = true;
    if(!isset($atts['all_areas'])) {
      $rojuaala_include_only_area = esc_attr( get_option( 'rojuaala-include-only-area' ) );
      if ( $rojuaala_include_only_area=="1") {
        $all = false;
      }
    } else {
      if ($atts['all_areas']=='false') {
        $all = false;
      }
    }

    $initParams = array(
      'P_ApiId' => $atts['filter_id'],
      'p1' => $rojuaala_client_id,
      'p2' => $rojuaala_api_key,
      'P_Lang' => $lang_request,
      'P_All' => $all
    );

    $initParams = array_merge($initParams,$others_params);

    $apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6, $initParams,URL_API_JUAALA_RESALES,ENDPOINTS_API_JUAALA_RESALES);

    $rs_juaala_search_form->features = [];
    if(isset($atts['show_advanced_search']) && $atts['show_advanced_search']=="true") {
      $responseFeatures = $apiController->getRequest($initParams,'getPropertiesFeatures');
      if (isset($responseFeatures['FeaturesData']) && isset($responseFeatures['FeaturesData']['Category'])) {
        $rs_juaala_search_form->features = $responseFeatures['FeaturesData']['Category'];
      }
    }

    $responseLocations = $apiController->getRequest($initParams,'getLocations');

    $responseTypes = $apiController->getRequest($initParams,'getPropertiesTypes');
    
    $rs_juaala_search_form->types = [];
    if (isset($responseTypes['PropertyTypes']) && isset($responseTypes['PropertyTypes']['PropertyType'])) {
      $rs_juaala_search_form->types = $responseTypes['PropertyTypes']['PropertyType'];
    }
     
    $rs_juaala_search_form->locations  = [];
    if (isset($responseLocations['LocationData']['ProvinceArea'])) {
      
      //comprobar si existe mas de una provincia/Area
      $locations_array = [];
      if (is_array($responseLocations['LocationData']['ProvinceArea'])) {
        if (isset($responseLocations['LocationData']['ProvinceArea']['ProvinceAreaName'])) {
          $locations_array[] = $responseLocations['LocationData']['ProvinceArea'];
        } else {
          //numero de ProvinceArea 
          foreach ($responseLocations['LocationData']['ProvinceArea'] as $province) {
            $locations_array[] = $province;
          }
        }
      } else {
        $locations_array[] =  $responseLocations['LocationData']['ProvinceArea']['Locations']['Location'];
      }
      $rs_juaala_search_form->locations = $locations_array;
    }
    $rs_juaala_search_form->filter_id = $atts['filter_id'];
    if (isset($atts['class'])) {
      $rs_juaala_search_form->class = $atts['class'];
    }
    if (isset($atts['class_collapse'])) {
      $rs_juaala_search_form->class_collapse = $atts['class_collapse'];
    }

    if (isset($atts['collapse'])) {
      $rs_juaala_search_form->collapse = $atts['collapse'];
    }

    if (isset($atts['state_collapse'])) {
      $rs_juaala_search_form->state_collapse = $atts['state_collapse'];
    }

    if (isset($atts['results_own_page'])) {
      $rs_juaala_search_form->results_own_page = $atts['results_own_page'];
    }

    //numero de propiedades encontradas
    if (isset($atts['number_properties'])) {
      $rs_juaala_search_form->number_properties = $atts['number_properties'];
    }

    if (isset($atts['no_show_areas']) && $atts['no_show_areas']=="true") {
      $rs_juaala_search_form->no_show_areas = $atts['no_show_areas'];
    }

    if (isset($atts['no_show_type']) && $atts['no_show_type']=="true") {
      $rs_juaala_search_form->no_show_type = $atts['no_show_type'];
    }

    if (isset($atts['no_show_rooms']) && $atts['no_show_rooms']=="true") {
      $rs_juaala_search_form->no_show_rooms = $atts['no_show_rooms'];
    }

    if (isset($atts['no_show_baths']) && $atts['no_show_baths']=="true") {
      $rs_juaala_search_form->no_show_baths = $atts['no_show_baths'];
    }

    if (isset($atts['no_show_to_price']) && $atts['no_show_to_price']=="true") {
      $rs_juaala_search_form->no_show_to_price = $atts['no_show_to_price'];
    }

    if (isset($atts['no_show_from_price']) && $atts['no_show_from_price']=="true") {
      $rs_juaala_search_form->no_show_from_price = $atts['no_show_from_price'];
    }

    if (isset($atts['no_show_reference_search']) && $atts['no_show_reference_search']=="true") {
      $rs_juaala_search_form->no_show_reference_search = $atts['no_show_reference_search'];
    }

    if (isset($atts['no_show_number_properties']) && $atts['no_show_number_properties']=="true") {
      $rs_juaala_search_form->no_show_number_properties = $atts['no_show_number_properties'];
    }

    if (isset($atts['no_show_new_development']) && $atts['no_show_new_development']=="true") {
      $rs_juaala_search_form->no_show_new_development = $atts['no_show_new_development'];
    }

    if (isset($atts['vertical']) && $atts['vertical']=="true") {
      $rs_juaala_search_form->vertical = $atts['vertical'];
    }

    if (isset($atts['p_musthavefeatures'])) {
      $rs_juaala_search_form->p_musthavefeatures = $atts['p_musthavefeatures'];
    }

    if (isset($atts['p_new_devs'])) {
      $rs_juaala_search_form->p_new_devs = $atts['p_new_devs'];
    }


    //para visualizar las propiedades del buscador avanzando. Uno por cada select
    $this->juaala_get_options_advanced_search($rs_juaala_search_form,$atts);
    
    $rojuaala_list_type_filter = get_option( 'rojuaala-list-type-filter' );
 
    $rs_juaala_search_form->url_target_form = admin_url() . 'admin-post.php';
    $rs_juaala_search_form->list_type_filter = $rojuaala_list_type_filter;
    $rs_juaala_search_form->icl_language_code = defined('ICL_LANGUAGE_CODE');
    $rs_juaala_search_form->icl_language_code_value = defined('ICL_LANGUAGE_CODE') ? ICL_LANGUAGE_CODE : '';
    $rs_juaala_search_form->pll_current_language = function_exists('pll_current_language');
    $rs_juaala_search_form->rs_request_uri = $_SERVER["REQUEST_URI"];  
    $rs_juaala_search_form->REQUEST = $_REQUEST;
    if (function_exists('pll_current_language')) {
      $rs_juaala_search_form->pll_current_language_value = pll_current_language();
    }
    if (isset($atts['include_title_page'])) {
     $rs_juaala_search_form->include_title = $atts['include_title_page']; 
    } else {
      $rs_juaala_search_form->include_title = 0; 
    }

    $rs_juaala_search_form->P_Lang = $lang_request;

    if (isset($atts['template']) && $atts['template']!='') {
      $rs_juaala_search_form->template = $atts['template'];
    }
    
    $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
    $form_string = $templatesController->getTemplate($rs_juaala_search_form, 'getTemplateSearchForm');
    return $form_string;

	}

  function juaala_rso_search_shortcode_map( $atts ) {


		if (empty($atts)) {
      $atts=[];
    }
  
    $rs_juaala_search_form = new stdClass();
    $is_form_rental = false;
    if (isset($atts['is_form_rental'])) {
      $is_form_rental = $atts['is_form_rental'];
      $rs_juaala_search_form->is_form_rental = $atts['is_form_rental'];
    }

    if (!isset($atts['filter_id'])) {
      //cogemos por defecto el configurado
      if (!$is_form_rental) {
        $atts['filter_id']  = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
      } else if ($is_form_rental=="short") {
        $atts['filter_id']  = esc_attr( get_option( 'rojuaala-default-filter-id-short-rental' ) );
      } else if ($is_form_rental=="long") {
        $atts['filter_id']  = esc_attr( get_option( 'rojuaala-default-filter-id-long-rental' ) );
      }
    } 

    //otros atributos pasados por parametro
    $others_params = [];
    $no_include_others_params = array(
                'filter_id',
                'class',
                'results_own_page',
                'class_collapse',
                'collapse',
                'state_collapse',
                'include_title_page',
                'is_form_rental',
                'number_properties'
              );
    foreach ($atts as $key => $value) {
      if (!in_array($key, $no_include_others_params)) {
        $others_params[$key] = $value;
      }
    }
    //comprobar que esté instalado polylang para ver que idioma es que hay que mandar
    $lang_request = $this->get_locale_page_rso_juaala();

    $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
    $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
    $all = true;
    $rojuaala_include_only_area = esc_attr( get_option( 'rojuaala-include-only-area' ) );
    if ( $rojuaala_include_only_area=="1") {
      $all = false;
    }

    $initParams = array(
      'P_ApiId' => $atts['filter_id'],
      'p1' => $rojuaala_client_id,
      'p2' => $rojuaala_api_key,
      'P_Lang' => $lang_request,
      'P_All' => $all
    );

    $initParams = array_merge($initParams,$others_params);

    $apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6, $initParams,URL_API_JUAALA_RESALES,ENDPOINTS_API_JUAALA_RESALES);

    $responseLocations = $apiController->getRequest($initParams,'getLocations');

    $responseTypes = $apiController->getRequest($initParams,'getPropertiesTypes');
    
    $rs_juaala_search_form->types = [];
    if (isset($responseTypes['PropertyTypes']) && isset($responseTypes['PropertyTypes']['PropertyType'])) {
      $rs_juaala_search_form->types = $responseTypes['PropertyTypes']['PropertyType'];
    }
     
    $rs_juaala_search_form->locations  = [];
    if (isset($responseLocations['LocationData']['ProvinceArea'])) {
      
      //comprobar si existe mas de una provincia/Area
      $locations_array = [];
      if (is_array($responseLocations['LocationData']['ProvinceArea'])) {
        foreach ($responseLocations['LocationData']['ProvinceArea'] as $province) {
          if (isset($province['Location']) && is_array($province['Location'])) {
            $locations_array = array_merge($locations_array,  $province['Location']);
          } else {
            if (isset($province['Locations'])) {
              if (is_array($province['Locations']['Location'])) {
                $locations_array = array_merge($locations_array,  $province['Locations']['Location']);
              } else { 
                $one_location[] = $province['Locations']['Location'];
                $locations_array = array_merge($locations_array,  $one_location);
              }
            } else if (isset($province['Location'])) {
              $one_location[] = $province['Location'];
              $locations_array = array_merge($locations_array,  $one_location);
            }
          }
        }
      } else {
        $locations_array =  $responseLocations['LocationData']['ProvinceArea']['Locations']['Location'];
      }
      $rs_juaala_search_form->locations = $locations_array;
    }
    $rs_juaala_search_form->filter_id = $atts['filter_id'];
    

    if (isset($atts['results_own_page'])) {
      $rs_juaala_search_form->results_own_page = $atts['results_own_page'];
    }

    //numero de propiedades encontradas
    if (isset($atts['number_properties'])) {
      $rs_juaala_search_form->number_properties = $atts['number_properties'];
    }

    
    $rojuaala_list_type_filter = get_option( 'rojuaala-list-type-filter' );
 
    $rs_juaala_search_form->url_target_form = admin_url() . '/admin-post.php';
    $rs_juaala_search_form->list_type_filter = $rojuaala_list_type_filter;
    $rs_juaala_search_form->icl_language_code = defined('ICL_LANGUAGE_CODE');
    $rs_juaala_search_form->icl_language_code_value = defined('ICL_LANGUAGE_CODE') ? ICL_LANGUAGE_CODE : '';
    $rs_juaala_search_form->pll_current_language = function_exists('pll_current_language');
    $rs_juaala_search_form->rs_request_uri = $_SERVER["REQUEST_URI"];  
    $rs_juaala_search_form->REQUEST = $_REQUEST;
    $rs_juaala_search_form->map_options =  esc_attr( get_option( 'rojuaala-map-integrarion-property' ) );
    $rs_juaala_search_form->api_key_map_google =   esc_attr( get_option( 'rojuaala-google-map-apikey' ) );
    if (function_exists('pll_current_language')) {
      $rs_juaala_search_form->pll_current_language_value = pll_current_language();
    }
    if (isset($atts['include_title_page'])) {
     $rs_juaala_search_form->include_title = $atts['include_title_page']; 
    } else {
      $rs_juaala_search_form->include_title = 0; 
    }

    $rs_juaala_search_form->P_Lang = $lang_request;

    if (isset($atts['template']) && $atts['template']!='') {
      $rs_juaala_search_form->template = $atts['template'];
    }
    
    $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
    $form_string = $templatesController->getTemplate($rs_juaala_search_form, 'getTemplateSearchMap');
    return $form_string;

	}

  public function juaala_rso_properties_by_refs_shortcode($atts) {

    $is_form_rental_search=false;
    $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
    $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
    $include_pagination = false;
    $include_sort = false;
    $include_num_results = false;
    $include_view_type = true;
    //si es distito de list -- será card
    $view_type = "card";
    $filter_id = "";

    if (isset($atts['filter_id'])) {
      $filter_id = $atts['filter_id'];

    } else {
      if (isset($_GET['filter_id'])) {
        $filter_id = $_GET['filter_id'];
      } else {
        //cogemos por defecto el configurado
        if (!$is_form_rental_search) {
          $filter_id  = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
        } else if ($is_form_rental_search=="short") {
          $filter_id  = esc_attr( get_option( 'rojuaala-default-filter-id-short-rental' ) );
        } else if ($is_form_rental_search=="long") {
          $filter_id  = esc_attr( get_option( 'rojuaala-default-filter-id-long-rental' ) );
        }
      }
    }

    $lang_request = $this->get_locale_page_rso_juaala();

    
    $properties = [];
    //por cada propiedad en el atributo references hacer petición
    if(isset($atts['references']) && $atts['references']!='') {
      //array de referencias
      $references = explode(",", $atts['references']);
      foreach($references as $ref) {
        if ($ref!='') {
          $initParamsProperty = array(
            'P_ApiId' => $filter_id,
            'p1' => $rojuaala_client_id,
            'p2' => $rojuaala_api_key,
            'P_Lang' => $lang_request,
            'P_RefId' => $ref,
          );
          $apiControllerProperty = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
          $responseProperty = $apiControllerProperty->getRequest($initParamsProperty,'getProperty');
          if (isset($responseProperty['Property'])) {
            $properties[] = $responseProperty['Property'];
          }
        }
      }
      $rs_juaala_templates_params = new stdClass();
      $rs_juaala_templates_params->rs_juaala_sresults_properties_search = $properties;  
      $rs_juaala_templates_params->rs_juaala_sresults_query_search = array("ApiId"=> $filter_id);
      $rs_juaala_templates_params->rs_juaala_spage_rs = 1;
      $rs_juaala_templates_params->rs_juaala_sresults_query_class =  '';
      $rs_juaala_templates_params->rs_juaala_sresults_init_params = $initParamsProperty;
      $rs_juaala_templates_params->rs_juaala_incluse_search = false;
      $rs_juaala_templates_params->rs_juaala_include_pagination = $include_pagination;
      $rs_juaala_templates_params->rs_juaala_include_sort = $include_sort;
      $rs_juaala_templates_params->rs_juaala_include_view_type = $include_view_type;
      $rs_juaala_templates_params->rs_juaala_include_num_results = $include_num_results;
      $rs_juaala_templates_params->rs_juaala_view_type = $view_type;  
      $rs_juaala_templates_params->rs_juaala_sresults_is_shortlist = 0;  
      $rs_juaala_templates_params->rs_request_uri = $_SERVER["REQUEST_URI"];  
      $rs_juaala_templates_params->rs_request_url_shortcode = plugin_dir_url(__DIR__) . 'do_shorcode/';
      $rs_juaala_templates_params->rs_get = $_GET;  
      $rs_juaala_templates_params->cut_description_property = CUT_DESCRIPTION_PROPERTY;
      $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
      $rs_juaala_templates_params->cookies =  $_COOKIE;
      $rs_juaala_templates_params->rs_juaala_sresults_properties_include_title_page = false;
      $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar = 0;
      $rs_juaala_templates_params->REQUEST = $_REQUEST;
      if (isset($id_featured_properties)) {
        $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar_id_api = $id_featured_properties;
      }

      $rs_juaala_templates_params->site_root = ABSPATH;
      $rs_juaala_templates_params->P_Lang = $lang_request;

      if (isset($atts['template']) && $atts['template']!='') {
        $rs_juaala_templates_params->template = $atts['template'];
      }

      if (isset($atts['sliders']) && $atts['sliders']!='') {
        $rs_juaala_templates_params->sliders = $atts['sliders'];
      }

      $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      $html_view = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateProperties');
      return $html_view;
    }

  }

  public function juaala_rso_properties_shortcode($atts) {

    if (!is_admin()) {

      if (empty($atts)) {
        $atts=[];
      }  

      //LAMADA A LA API CON LOS PARAMETROS
      $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
      $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
      $include_search = false;
      $class_include_search = "";
      $results_own_page_search=false;
      $is_form_rental_search=false;
      $class="";
      $include_pagination = true;
      $include_sort = true;
      $include_num_results = true;
      $include_view_type = true;
      //si es distito de list -- será card
      $view_type = "card";

      $filter_id = "";

      if (isset($atts['is_form_rental_search'])) {
        $is_form_rental_search = $atts['is_form_rental_search'];
      }

      if (isset($atts['filter_id'])) {
        $filter_id = $atts['filter_id'];

      } else {
        if (isset($_GET['filter_id'])) {
          $filter_id = $_GET['filter_id'];
        } else {
          //cogemos por defecto el configurado
          if (!$is_form_rental_search) {
            $filter_id  = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
          } else if ($is_form_rental_search=="short") {
            $filter_id  = esc_attr( get_option( 'rojuaala-default-filter-id-short-rental' ) );
          } else if ($is_form_rental_search=="long") {
            $filter_id  = esc_attr( get_option( 'rojuaala-default-filter-id-long-rental' ) );
          }
        }
      }

      //si viene la referencia, montar la url de una propiedad genérica
      // pasando como parametro la referencia
      if (isset($_GET['reference']) && $_GET['reference']!='') {
        $ref = $_GET['reference'];
        $url_property = $this->get_url_details_property(sanitize_title("ref"),$ref,$filter_id);
        if ( wp_redirect( $url_property ) ) {
          exit;
        }
      
      }

      
    

      if (isset($atts['include_search'])) {
        $include_search = $atts['include_search'];
      }
      if (isset($atts['class_include_search'])) {
        $class_include_search = $atts['class_include_search'];
      }
      if (isset($atts['results_own_page_search'])) {
        $results_own_page_search = $atts['results_own_page_search'];
      }

      if (isset($atts['include_pagination'])) {
        $include_pagination = $atts['include_pagination'];
      }

      if (isset($atts['include_sort'])) {
        $include_sort = $atts['include_sort'];
      }

      if (isset($atts['include_num_results'])) {
        $include_num_results = $atts['include_num_results'];
      }
      
      if (isset($atts['class'])) {
        $class = $atts['class'];
      }

      if (isset($atts['view_type'])) {
        $view_type = $atts['view_type'];
      }

      if (isset($atts['include_view_type'])) {
        $include_view_type = $atts['include_view_type'];
      }

      

      //aplicar demás filtros

      $others_params= [];


      if (isset($_GET['type'])) {
        $type = $_GET['type'];
          if (is_array($type)) {
            $type =implode(",", $type);
          } 
          $others_params['P_PropertyTypes'] = $type;
      } else {
        if (isset($atts['type'])) {
          $others_params['P_PropertyTypes'] = $atts['type'];
        } 
      }
      if (isset($atts['location'])) {
        $location = $atts['location'];
        $others_params['P_Location'] = $location;
      } else {
        if (isset($_GET['location'])) {
          $location = $_GET['location'];
          if (is_array($location)) {
            $location =implode(",", $location);
          }
          $others_params['P_Location'] = $location;
        }
      }

      if (isset($_GET['price_from'])) {
        $price_from = $_GET['price_from'];
        $others_params['P_Min'] = $price_from;
      }

      if (isset($_GET['price_to'])) {
        $price_to = $_GET['price_to'];
        $others_params['P_Max'] = $price_to;
      }

      if (isset($_GET['beds'])) {
        $beds = $_GET['beds'];
        $others_params['P_Beds'] = $beds;
      }

      if (isset($_GET['baths'])) {
        $baths = $_GET['baths'];
        $others_params['P_Baths'] = $baths;
      }

      if (isset($_GET['query_id'])) {
        $others_params['P_QueryId'] = $_GET['query_id'];
      }

      $page_rs = 1;
      if (isset($_GET['page_rs'])) {
        $others_params['p_PageNo'] = $_GET['page_rs'];
        $page_rs = $_GET['page_rs'];
      }

      if (isset($_GET['p_sortyype'])) {
        $order = $_GET['p_sortyype'];
        $others_params['P_SortType'] = $order;
      } else {
        if (isset($atts['p_sortyype'])) {
          $order = $atts['p_sortyype'];
          $others_params['P_SortType'] = $order;
        }
      }

      if (isset($_GET['p_new_devs'])) {
        $new_developments = $_GET['p_new_devs'];
        $others_params['p_new_devs'] = $new_developments;
      } else {
        if (isset($atts['p_new_devs'])) {
          $new_developments = $atts['p_new_devs'];
          $others_params['p_new_devs'] = $new_developments;
        }
      }

      if (isset($_GET['p_new_devs'])) {
        $p_new_devs = $_GET['p_new_devs'];
        $others_params['P_new_devs'] = $p_new_devs;
      } else {
        if (isset($atts['p_new_devs'])) {
          $p_new_devs = $atts['p_new_devs'];
          $others_params['p_new_devs'] = $p_new_devs;
        }
      }

      //obtener la lista del buscador avanzado. Viene con atributos llamado features
      foreach ($atts as $key=>$value) {
        $pos = strrpos($key, "features");
        if ($pos !== false) { 
          $features = explode(",", $value);
          //vienen separados por coma
          if (is_array($features)) {
            foreach($features as $v) {
              $others_params[$v] = "1";
            }
          } else {
            $others_params[$value] = "1";
          }
        }
      }

      //obtener la lista del buscador avanzado. Viene con parametros llamado features
      foreach ($_GET as $key=>$value) {
        $pos = strrpos($key, "features");
        if ($pos !== false) { 
          if (is_array($value)) {
            foreach($value as $v) {
              $others_params[$v] = "1";
            }
          } else {
            $others_params[$value] = "1";
          }
        }
      }

      if (isset($_GET['P_MustHaveFeatures'])) {
        $P_MustHaveFeatures = $_GET['P_MustHaveFeatures'];
        $others_params['P_MustHaveFeatures'] = $P_MustHaveFeatures;
      } else {
        if (isset($atts['p_musthavefeatures'])) {
          $P_MustHaveFeatures = $atts['p_musthavefeatures'];
          $others_params['P_MustHaveFeatures'] = $P_MustHaveFeatures;
        }
      }

      if (isset($_GET['p_PageSize'])) {
        $p_PageSize = $_GET['p_PageSize'];
        $others_params['p_PageSize'] = $p_PageSize;
      } else {
        if (isset($atts['p_pagesize'])) {
          $p_PageSize = $atts['p_pagesize'];
          $others_params['p_PageSize'] = $p_PageSize;
        } else {
          $others_params['p_PageSize'] = 10;
        }
      }
    

      $lang_request = $this->get_locale_page_rso_juaala();

      $initParams = array(
        'P_ApiId' => $filter_id,
        'p1' => $rojuaala_client_id,
        'p2' => $rojuaala_api_key,
        'P_Lang' => $lang_request
      );

      
      $initParams = array_merge($initParams,$others_params);

    
      $apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
    
    
      $response = $apiController->getRequest($initParams,'getProperties');

      
      
      if (isset($response['Property'])) {
        $rs_juaala_sresults_properties_search = $response['Property'];
      } else {
        $rs_juaala_sresults_properties_search = [];
      }

      if (isset($response['QueryInfo'])) {
        $rs_juaala_sresults_query_search = $response['QueryInfo'];
      } else {
        $rs_juaala_sresults_query_search = [];
      }

    
      $rs_juaala_sresults_properties_sidebar = 0;
      //Esta parte irá por ajax para no cargar mucho la rederización
      if (isset($atts['id_featured_properties']) && $atts['id_featured_properties']!="") {
        $id_featured_properties  = $atts['id_featured_properties'];
        if ($atts['id_featured_properties']=="true") {
          $id_featured_properties = esc_attr( get_option( 'rojuaala-default-filter-id-featured' ) );
          $atts['id_featured_properties'] = $id_featured_properties;
        }
        
        //buscamos propiedades destacadas
        $initParamsFeatured = array(
          'P_ApiId' => $id_featured_properties,
          'p1' => $rojuaala_client_id,
          'p2' => $rojuaala_api_key,
          'P_Lang' => $lang_request,
          'P_SortType' => '3'
        );

        $apiControllerFeatured = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);

        $responseFeatured = $apiControllerFeatured->getRequest($initParamsFeatured, 'getProperties');
        
        
        $rs_juaala_sresults_properties_sidebar = count($responseFeatured['Property']);
        
      } 
      $html_form_search = '';
      if (isset($atts['include_search'])) {
        if ($atts['include_search']) {
          $search_params = [];
          $search_params['filter_id'] =  $filter_id;
          $search_params['class'] =  $class_include_search;
          $search_params['results_own_page'] =  $results_own_page_search;
          $search_params['is_form_rental'] = $is_form_rental_search;

          if (isset($atts['class_collapse'])) {
            $search_params['class_collapse'] = $atts['class_collapse'];
          }
      
          if (isset($atts['collapse'])) {
            $search_params['collapse'] = $atts['collapse'];
          }
      
          if (isset($atts['state_collapse'])) {
            $search_params['state_collapse'] = $atts['state_collapse'];
          }

          $search_params['number_properties'] =  $response['QueryInfo']['PropertyCount'];

          $initParamsSearch = array_merge($initParams,$search_params);
          $html_form_search = $this->juaala_rso_search_shortcode($initParamsSearch);
        }
      }

    
      $include_title_page = false;
      if (isset($atts['include_title_page'])) {
        $include_title_page = $atts['include_title_page'];
      }

      $rs_juaala_templates_params = new stdClass();
      $rs_juaala_templates_params->rs_juaala_sresults_properties_search = $rs_juaala_sresults_properties_search;  
      $rs_juaala_templates_params->rs_juaala_sresults_query_search = $rs_juaala_sresults_query_search;
      $rs_juaala_templates_params->rs_juaala_spage_rs = $page_rs;
      $rs_juaala_templates_params->rs_juaala_sresults_query_class =  $class;
      $rs_juaala_templates_params->rs_juaala_sresults_init_params = $initParams;
      $rs_juaala_templates_params->rs_juaala_incluse_search = $include_search;
      $rs_juaala_templates_params->rs_juaala_include_pagination = $include_pagination;
      $rs_juaala_templates_params->rs_juaala_include_sort = $include_sort;
      $rs_juaala_templates_params->rs_juaala_include_view_type = $include_view_type;
      $rs_juaala_templates_params->rs_juaala_include_num_results = $include_num_results;
      $rs_juaala_templates_params->rs_juaala_view_type = $view_type;  
      $rs_juaala_templates_params->rs_juaala_sresults_is_shortlist = 0;  
      $rs_juaala_templates_params->rs_request_uri = $_SERVER["REQUEST_URI"];  
      $rs_juaala_templates_params->rs_request_url_shortcode = plugin_dir_url(__DIR__) . 'do_shorcode/';
      $rs_juaala_templates_params->rs_get = $_GET;  
      $rs_juaala_templates_params->cut_description_property = CUT_DESCRIPTION_PROPERTY;
      $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
      $rs_juaala_templates_params->cookies =  $_COOKIE;
      $rs_juaala_templates_params->rs_juaala_sresults_properties_include_title_page = $include_title_page;
      $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar = $rs_juaala_sresults_properties_sidebar;
      $rs_juaala_templates_params->REQUEST = $_REQUEST;
      if (isset($id_featured_properties)) {
        $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar_id_api = $id_featured_properties;
      }

      $rs_juaala_templates_params->site_root = ABSPATH;
      $rs_juaala_templates_params->P_Lang = $lang_request;

      if (isset($atts['template']) && $atts['template']!='') {
        $rs_juaala_templates_params->template = $atts['template'];
      }
      
      if (isset($atts['sliders']) && $atts['sliders']!='') {
        $rs_juaala_templates_params->sliders = $atts['sliders'];
      }

      $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      $html_view = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateProperties');
      return $html_form_search . $html_view;
    }
  }



  public function juaala_rso_property_shortcode($atts) {

    global $details_property;
  
    if (!is_admin()) { 
  
      $P_ApiId = $_GET['type'];
      
      global $wp;
      $rs_juaala_templates_params = new stdClass();
      $rs_juaala_templates_params->rs_juaala_property_details_releated_type = $P_ApiId;  
      $rs_juaala_templates_params->rs_juaala_property_details = $details_property;
      $rs_juaala_templates_params->css_class_container_property_details = esc_attr( get_option( 'rojuaala-css-class-container-details-property' ) );
      $rs_juaala_templates_params->cookies =  $_COOKIE;
      $rs_juaala_templates_params->rs_request_url_shortcode = plugin_dir_url(__DIR__) . 'do_shorcode/';
      $rs_juaala_templates_params->id_contact_form = esc_attr( get_option( 'rojuaala-id-contact-form-7-property' ) );
      $rs_juaala_templates_params->id_contact_wp_forms = esc_attr( get_option('rojuaala-id-contact-wp-forms-property' ) );
      $rs_juaala_templates_params->map_options =  esc_attr( get_option( 'rojuaala-map-integrarion-property' ) );
      $rs_juaala_templates_params->api_key_map_google =   esc_attr( get_option( 'rojuaala-google-map-apikey' ) );
      $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
      $url_page =  home_url( $wp->request );
      $url_page = $url_page .  "?type=" . $P_ApiId;
      $rs_juaala_templates_params->url_page =  $url_page;
      $rs_juaala_templates_params->do_shortcode_ssba_buttons =  false;
      $rs_juaala_templates_params->url_pdf =  plugin_dir_url( __DIR__ ) . 'pdf.php?type=' . $P_ApiId; 
      if (isset($atts['template']) && $atts['template']!='') {
        $rs_juaala_templates_params->template = $atts['template'];
      }
  
  
      if (is_plugin_active("simple-share-buttons-adder/simple-share-buttons-adder.php")) { 
        $rs_juaala_templates_params->do_shortcode_ssba_buttons =  true;
      }
      
      
      if ( get_option('rojuaala-image-pdf')=='') {
        $image = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );
        $image_src_pdf = $image[0];
      } else {
        $image_src_pdf = get_option('rojuaala-image-pdf');
      }
  
      $rs_juaala_templates_params->image_src_pdf = $image_src_pdf;
      $rs_juaala_templates_params->text_contact_pdf = get_option( 'rojuaala-text-contact-pdf' );
      $rs_juaala_templates_params->text_footer_pdf =  get_option( 'rojuaala-text-footer-pdf' );
      $lang_request = $this->get_locale_page_rso_juaala();
      $rs_juaala_templates_params->P_Lang = $lang_request;
  
      $rojuaala_include_search = esc_attr( get_option( 'rojuaala-include-search-in-property-details-page' ) );
      $html_form_search = '';
      if ($rojuaala_include_search && $rojuaala_include_search==1) {
        $css_class_search = esc_attr( get_option( 'rojuaala-css-include-search-in-property-details-page' ) );
        $search_params = [];
        $search_params['filter_id'] =  $P_ApiId;
        $search_params['class'] = $css_class_search;
        $search_params['collapse'] = 'true';
        $search_params['state_collapse'] = 'close';
        $search_params['class_collapse'] = 'property-search-expand texture-background d-block text-center text-white py-2';
        if (isset($atts['template']) && $atts['template']!='') {
          $search_params['template'] = $atts['template'];
        }
        $html_form_search = $this->juaala_rso_search_shortcode($search_params);
      }
  
      if (isset($atts['habeno_id']) && $atts['habeno_id']!='') {
        $rs_juaala_templates_params->habeno_id = $atts['habeno_id'];
      }

      if (isset($atts['id_contact_form_7']) && $atts['id_contact_form_7']!='') {
        $rs_juaala_templates_params->id_contact_form = $atts['id_contact_form_7'];
      }

      if (isset($atts['id_wp_forms']) && $atts['id_wp_forms']!='') {
        $rs_juaala_templates_params->id_wp_forms = $atts['id_wp_forms'];
      }
      $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      $html_view = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateProperty');

      //sustituir los shortcodes por la ejecución
      $number_version = intval(str_replace(".", "", $this->version));
      //prioridad para contact forms 7
      if (
        isset($rs_juaala_templates_params->id_contact_form ) 
          && $rs_juaala_templates_params->id_contact_form!=''
          && $number_version>107) {

        $title = $details_property['PropertyType']['NameType'] . ' ' . __('in','rsonline-juaala') . ' ' . $details_property['Location'] . ', ' . $details_property['Area'];
        $property_email = $this->juaala_rso_property_email_info($details_property ,$title ,0, $url_page,true);
        $shortcode =  do_shortcode( '[contact-form-7 id="' . esc_attr( get_option('rojuaala-id-contact-form-7-property' ) ) . '" property_email="'. $property_email . '" title="Property"]' );
        $html_view =  str_replace("[rs-juaala-shortcode-contact-form-7 id='" . $rs_juaala_templates_params->id_contact_form . "']", $shortcode,  $html_view );
      } else {
        if (
          isset($rs_juaala_templates_params->id_contact_wp_forms ) 
            && $rs_juaala_templates_params->id_contact_wp_forms!=''
            && $number_version>107) {

          $shortcode =  do_shortcode( '[wpforms id="' . esc_attr( get_option('rojuaala-id-contact-wp-forms-property' ) ) . '"/]' );
          $html_view =  str_replace("[rs-juaala-shortcode-wp-forms id='" . $rs_juaala_templates_params->id_contact_wp_forms . "']", $shortcode,  $html_view );
        } 
      }

      if ($number_version>107) {
        if (is_plugin_active("simple-share-buttons-adder/simple-share-buttons-adder.php")) { 
          $shortcode_ssba = do_shortcode('[ssba-buttons]'); 
          $html_view =  str_replace("[rs-juaala-ssba-buttons]", $shortcode_ssba,  $html_view );
        }
      }


      return  $html_form_search . $html_view;
  
    }
  }

  public function juaala_rso_property_hero_shortcode($atts) {

    global $details_property;
  
    if (!is_admin()) { 

      if (!isset($atts['filter_id'])) {

        $is_form_rental = false;
        if (isset($atts['is_form_rental'])) {
          $is_form_rental = $atts['is_form_rental'];
        }
        //cogemos por defecto el configurado
        if (!$is_form_rental) {
          $P_ApiId  = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
        } else if ($is_form_rental=="short") {
          $P_ApiId  = esc_attr( get_option( 'rojuaala-default-filter-id-short-rental' ) );
        } else if ($is_form_rental=="long") {
          $P_ApiId  = esc_attr( get_option( 'rojuaala-default-filter-id-long-rental' ) );
        } else {
          $P_ApiId  = esc_attr( get_option( 'rojuaala-default-filter-id' ) );
        }
        $atts['filter_id'] = $P_ApiId;
      } else {
        $P_ApiId = $atts['filter_id'];
      }

      $this->juaala_rso_property_page($atts); 

      global $wp;
      $rs_juaala_templates_params = new stdClass();
      $rs_juaala_templates_params->rs_juaala_property_type = $P_ApiId;  
      $rs_juaala_templates_params->rs_juaala_property_details = $details_property;
      $rs_juaala_templates_params->cookies =  $_COOKIE;
      $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
      $url_page =  home_url( $wp->request );
      $url_page = $url_page .  "?type=" . $P_ApiId;
      $rs_juaala_templates_params->url_page =  $url_page;
  
      if (isset($atts['template']) && $atts['template']!='') {
        $rs_juaala_templates_params->template = $atts['template'];
      }    
      
      $lang_request = $this->get_locale_page_rso_juaala();
      $rs_juaala_templates_params->P_Lang = $lang_request;

      //recoger todos los atts y añadirlos como referencia al objeto
      //url_image, title, subtitle, description, to_price, from_price
      foreach($atts as $key=>$value) {
        if ($key!='filter_id' && $key!='is_form_rental' && $key!='template' && $key!='reference') {
          $rs_juaala_templates_params->{"" . $key} = $value;
        }
      }
  
      $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      $html_view = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplatePropertyHero');
      return  $html_view;
  
    }
  }

  public  function juaala_rso_shortlist_shortcode($atts) {
    //muestra la lista de propiedades añadidas a favoritas
    //carga la página que muestra los shorlist haciendo llamada ajax
    $class= '';
    $template = '';
    $view_type = 'card';
    if (isset($atts['class'])) {
      $class= $atts['class'];
    }
    if (isset($atts['template']) && $atts['template']!='') {
      $template = $atts['template'];
    }
    if (isset($atts['view_type']) && $atts['view_type']!='') {
      $view_type = $atts['view_type'];
    }
    set_query_var ('class', $class);
    set_query_var ('template', $template);
    set_query_var ('view_type', $view_type);
    ob_start();
    include __DIR__ . '/partials/rsonline-juaala-properties-shortlist-noajax.php';
    return ob_get_clean();
  
  }

  public  function juaala_rso_compare_shortcode($atts) {
 

      $class= '';
      $template = '';
      if (isset($atts['class'])) {
        $class= $atts['class'];
      }
      if (isset($atts['template']) && $atts['template']!='') {
        $template = $atts['template'];
      }
      // Check if cookie is already set
      $properties= [];
      $response_properties['Property'] = [];
      
      $lang_request = $this->get_locale_page_rso_juaala();
     
      if(isset($_COOKIE['wpb_rso_juaala_compare'])) {
  
        
        //lista de propiedades seteada para comparar
        $properties = json_decode(stripslashes($_COOKIE['wpb_rso_juaala_compare']), true);
        
        
        foreach($properties as $property) {
          
          if ($property) {
    
            $porciones = explode(";", $property);
            //hacemos llamada para buscar la propiedad
            
            $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
            $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
         
            $initParams = array(
              'P_ApiId' => $porciones[1],
              'p1' => $rojuaala_client_id,
              'p2' => $rojuaala_api_key,
              'P_RefId' =>  $porciones[0],
              'P_Lang' => $lang_request
            );
    
            $apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
            $response = $apiController->getRequest($initParams,'getProperty');
            if (isset($response['Property'])) {
              $response['Property']['id_filter'] = $porciones[1];
              $response_properties['Property'][] = $response['Property'];
            }
          }
        }
        
  
        $rs_juaala_templates_params = new stdClass();
        $rs_juaala_templates_params->rs_juaala_sresults_properties_search =$response_properties['Property'];  
        $rs_juaala_templates_params->rs_juaala_sresults_query_class =  $class;
        $rs_juaala_templates_params->rs_request_uri = $_SERVER["REQUEST_URI"];  
        $rs_juaala_templates_params->rs_request_url = plugin_dir_url(__DIR__);
        $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
        $rs_juaala_templates_params->cookies =  $_COOKIE;
        $rs_juaala_templates_params->P_Lang = $lang_request;
        $rs_juaala_templates_params->template = $template;
      
        $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
        
        $html_compare = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateCompare');
  
        
        return $html_compare;
        
      } 
  
  }
  

  protected function get_locale_page_rso_juaala() {
		$lang_request = 1; //POR DEFECTO INGLÈS
		if (defined('ICL_LANGUAGE_CODE')) {
			if (isset(LANG_RS_ONLINE[ICL_LANGUAGE_CODE])) {
				$lang_request = LANG_RS_ONLINE[ICL_LANGUAGE_CODE];
			}
		}
		else if (function_exists('pll_current_language'))  {
			$lang = pll_current_language();
			if (isset(LANG_RS_ONLINE[$lang])) {
				$lang_request = LANG_RS_ONLINE[$lang];
			}
		}  else {
			//idioma de la instalacion de wordpress
			$lang_wordpress = get_locale();
			if ($lang_wordpress) {
				$lang = substr($lang_wordpress, 0, 2);
				if (isset(LANG_RS_ONLINE[$lang])) {
					$lang_request = LANG_RS_ONLINE[$lang];
				}
			} else {
				//idioma del navegador
				substr($_SERVER['HTTP_ACCEPT_LANGUAGE'], 0, 2);
				$lang = substr($_SERVER['HTTP_ACCEPT_LANGUAGE'], 0, 2);
				if (isset(LANG_RS_ONLINE[$lang])) {
					$lang_request = LANG_RS_ONLINE[$lang];
				}
			}
		}
		return $lang_request;
	}

  protected function get_url_details_property($slug, $ref,$filter_id,$lang='') {

    $default_lang_plugin = esc_attr( get_option( 'rojuaala-default-lang' ) );
    $pre_lang_url = '';
    $id_page_details_property = $this->juaala_rso_get_url_details_property_lang();
  
    if (isset($lang) && $lang!='') {
      $default_lang = $lang;
    } else {
  
      if (defined('ICL_LANGUAGE_CODE')) {
        $default_lang = ICL_LANGUAGE_CODE;
      } else {
        //POLYLANG
        if (function_exists('pll_current_language')) {
          $default_lang = pll_current_language();
        }
        if(!isset($default_lang) || !$default_lang) {
          $lang_wordpress = get_locale();
          if ($lang_wordpress) {
            $default_lang = substr($lang_wordpress, 0, 2);
          }
        }
      }
    }

    $permanent = get_permalink($id_page_details_property);
    if (strpos($permanent, "?page_id=" . $id_page_details_property)!==false) {
      return $permanent;
    } else {
      $value_url = URL_PROPERTY_DETAILS_LANG[$default_lang];
    
      if ($default_lang_plugin!=='' && $default_lang_plugin!=$default_lang) {
        $pre_lang_url = $default_lang . '/';
      }
    
      $link_page_prorperty = get_site_url(). '/' .  $pre_lang_url . $value_url . '/';
      $url_property = $slug . "/" .  $ref;
      $url_property = $link_page_prorperty . $url_property . "?type=" . $filter_id;
      return  $url_property;
    }
  }

  protected function get_url_details_property_template($lang='') {

    $default_lang_plugin = esc_attr( get_option( 'rojuaala-default-lang' ) );
    $pre_lang_url = '';
    $id_page_details_property = $this->juaala_rso_get_url_details_property_lang();
    if (isset($lang) && $lang!='') {
      $default_lang = $lang;
    } else {
  
      if (defined('ICL_LANGUAGE_CODE')) {
        $default_lang = ICL_LANGUAGE_CODE;
      } else {
        //POLYLANG
        if (function_exists('pll_current_language')) {
          $default_lang = pll_current_language();
        }
        if(!isset($default_lang) || !$default_lang) {
          $lang_wordpress = get_locale();
          if ($lang_wordpress) {
            $default_lang = substr($lang_wordpress, 0, 2);
          }
        }
      }
    }
    $permanent = get_permalink($id_page_details_property);
    if (strpos($permanent, "?page_id=" . $id_page_details_property)!==false) {
      return $permanent;
    } else {
      $value_url = URL_PROPERTY_DETAILS_LANG[$default_lang];
  
      if ($default_lang_plugin!=='' && $default_lang_plugin!=$default_lang) {
        $pre_lang_url = $default_lang . '/';
      }
    
      $link_page_prorperty = get_site_url(). '/' .  $pre_lang_url . $value_url . '/';
      
      return $link_page_prorperty;
    }
    
    
  }

  protected function juaala_rso_get_url_details_property_lang() {

    $id_page_details_property = 3334;

    $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-property-details' ) );
    if(isset($id_page_result_option) && $id_page_result_option!='') {
      if ( 'publish' === get_post_status( $id_page_result_option ) ) {
        $id_page_details_property = $id_page_result_option;
      }
    }
    if (defined('ICL_LANGUAGE_CODE')) {
      $id = icl_object_id($id_page_details_property, 'page', false, ICL_LANGUAGE_CODE);
      if ($id) {
        $id_page_details_property = $id;
      }
    } else {
      //POLYLANG
      if (function_exists('pll_current_language')) {
        if (function_exists('pll_get_post'))  {
          $id =  pll_get_post($id_page_details_property,  pll_current_language());
          if ($id) {
            $id_page_details_property = $id;
          }
        }
      }
    }
    return $id_page_details_property;
  }

  public function juaala_rso_addnew_query_vars($vars) {   
    $vars[] = 'ref_property';
    return $vars;
  }

  public function juaala_rso_custom_form_submit() {
      
    //comprobar que el está instalado el plugin polylang para ver la página según la traduccion
    $id_page_result = 3333;
    //si se ha definido el id la página en el plugin establecerlo si existe la página
    $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-result-search' ) );
    if(isset($id_page_result_option) && $id_page_result_option!='') {
      if ( 'publish' === get_post_status( $id_page_result_option ) ) {
        $id_page_result = $id_page_result_option;
      }
    }
  
     $default_lang_plugin = esc_attr( get_option( 'rojuaala-default-lang' ) );
     if (isset($_POST['lang'])) {
      $lang = $_POST['lang'];
    } else {
      $lang =  $default_lang_plugin;
    }
    
    if (defined('ICL_LANGUAGE_CODE')) {
      //comprobar si está instalado el plugin wmpl
      $id = icl_object_id($id_page_result, 'page', false, $lang);
      if ($id) {
        $id_page_result = $id;
      }
    } else {
      //POLYLANG
      if (function_exists('pll_get_post') && function_exists('pll_current_language'))  {
        $id_page_result_lang =  pll_get_post( $id_page_result, $lang);
        if ($id_page_result_lang) {
          $id_page_result = $id_page_result_lang;
        }
      }
    }
  
    $base_redirection = get_page_link($id_page_result);
  
    //Montar la url con los parámetros
    if (isset($_POST['type'])) {
      $strTypes = implode (",", $_POST['type']);
      $base_redirection =  $base_redirection . '?type=' . $strTypes;
    } else {
      $base_redirection =  $base_redirection . '?type=';
    }
    if (isset($_POST['location'])) {
      $strLocations = implode (",", $_POST['location']);
      $base_redirection =  $base_redirection . '&location=' . $strLocations;
    }
  
    if (isset($_POST['price_from'])) {
      $base_redirection =  $base_redirection . '&price_from=' . $_POST['price_from'];
    }
  
    if (isset($_POST['price_to'])) {
      $base_redirection =  $base_redirection . '&price_to=' . $_POST['price_to'];
    }
  
    $base_redirection =  $base_redirection . '&filter_id=' . $_POST['filter_id'];
  
    if (isset($_POST['beds'])) {
      $base_redirection =  $base_redirection . '&beds=' . urlencode($_POST['beds']);
    }
  
    if (isset($_POST['baths'])) {
      $base_redirection =  $base_redirection . '&baths=' . urlencode($_POST['baths']);
    }
  
    if (isset($_POST['reference'])) {
      $base_redirection =  $base_redirection . '&reference=' . $_POST['reference'];
    }
    if (isset($_POST['P_SortType'])) {
      $base_redirection =  $base_redirection . '&P_SortType=' . $_POST['p_sortyype'];
    }
  
    if (isset($_POST['p_new_devs'])) {
      $base_redirection =  $base_redirection . '&p_new_devs=' . $_POST['p_new_devs'];
    }
  
    if (isset($_POST['reference']) && $_POST['reference']!='') {
      $ref = $_POST['reference'];
      $url_property = $this->get_url_details_property(sanitize_title("ref"),$ref,$_POST['filter_id'],$lang);
      if ( wp_redirect( $url_property ) ) {
        die();
        exit;
      }
    }

    //datos del buscador avanzado
    //obtener la lista del buscador avanzado. Viene con parametros llamado features
    foreach ($_POST as $key=>$value) {
      $pos = strrpos($key, "features");
      if ($pos !== false) { 
        if (is_array($value)) {
          foreach($value as $v) {
            $base_redirection =  $base_redirection . '&' . $key . '[]=' . $v;
          }
        } else {
          $base_redirection =  $base_redirection . '&' . $key  . '=' . $value;
        }
      }
    }
    if (isset($_POST['P_MustHaveFeatures']) && $_POST['P_MustHaveFeatures']!='') {
      $base_redirection =  $base_redirection . '&P_MustHaveFeatures=' . $_POST['P_MustHaveFeatures'];
    }

    wp_redirect($base_redirection);
    die();
  }

  function juaala_rso_custom_rewrite_basic() {
    global $wp_rewrite;
    $id_page_details_property = 3334;

    $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-property-details' ) );
    if(isset($id_page_result_option) && $id_page_result_option!='') {
      if ( 'publish' === get_post_status( $id_page_result_option ) ) {
        $id_page_details_property = $id_page_result_option;
      }
    }

    $default_lang = esc_attr( get_option( 'rojuaala-default-lang' ) );
    if(!$default_lang) {
      $lang_wordpress = get_locale();
      if ($lang_wordpress) {
        $default_lang = substr($lang_wordpress, 0, 2);
      }
    } 
    
    foreach(URL_PROPERTY_DETAILS_LANG as $key => $value) {

      if ($key==$default_lang) {
        add_rewrite_rule('^' . $value . '/(.*)/(.*)', 'index.php?page_id='. $id_page_details_property . '&ref_property=$matches[2]','top');
      } else {
        //buscamos el id de la pàgina si la hubiese
        if( !function_exists('is_plugin_active') ) {
          include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        }
        if (defined('ICL_LANGUAGE_CODE') && (is_plugin_active("wpml-string-translation/plugin.php") || is_plugin_active("sitepress-multilingual-cms/sitepress.php"))) {
          //para plugin WPML. El rewrite no lleva el locale delante
          //sacamos el id página correspondiente al idioma
          //comprobar si está instalado el plugin wmpl
          $id = icl_object_id($id_page_details_property, 'page', false,  $key);
          if ($id && $id !=$id_page_details_property) {
            add_rewrite_rule('^' . $value . '/(.*)/(.*)', 'index.php?page_id='. $id . '&ref_property=$matches[2]','top');
          }
        } else {
          if (function_exists('pll_current_language')) {
            //polylang segunda opcion
            if (function_exists('pll_get_post'))  {
              $id =  pll_get_post( $id_page_details_property,  $key);
              if ($id && $id !=$id_page_details_property) {
                add_rewrite_rule('^' . $key .'/' . $value . '/(.*)/(.*)', 'index.php?page_id='. $id . '&ref_property=$matches[2]','top');
              }
            }
          }
        }
      }
      
      //echo '^' . $key . '/' . $value . '/(.*)/(.*)', 'index.php?pagename=property-details&ref_property=$matches[2]';
      //add_rewrite_rule('^' . $key . '/' . $value . '/(.*)/(.*)', 'index.php?pagename=property-details&ref_property=$matches[2]');
    }
    $wp_rewrite->flush_rules();
  }

  public function juaala_rso_details_prorperty_post_action( $post_object ) {
    if (!is_admin()) {
      $id_page_details = 3334;
      $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-property-details' ) );
      if(isset($id_page_result_option) && $id_page_result_option!='') {
        if ( 'publish' === get_post_status( $id_page_result_option ) ) {
          $id_page_details = $id_page_result_option;
        }
      }
      if (defined('ICL_LANGUAGE_CODE')) {
        //comprobar si está instalado el plugin wmpl
        $id = icl_object_id($id_page_details, 'page', false, ICL_LANGUAGE_CODE);
        if ($id) {
          $id_page_details = $id;
        }
      } else { 
        if (function_exists('pll_current_language')) {
          if (function_exists('pll_get_post'))  {
            $id =  pll_get_post($id_page_details,  pll_current_language());
            if ($id) {
              $id_page_details = $id;
            }
          }
        }
      }
  
      if ($post_object->ID==$id_page_details) {
        global $property_title;
        $post_object->post_title = $property_title;
      }
    }
  }

  public function juaala_rso_set_property_details_page( $query ) {

    if (!is_admin()) {
      //por id de página
  
      $id_page_details = 3334;
      $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-property-details' ) );
      if(isset($id_page_result_option) && $id_page_result_option!='') {
        if ( 'publish' === get_post_status( $id_page_result_option ) ) {
          $id_page_details = $id_page_result_option;
        }
      }
  
      //comprobar si viene el parametro ref_property y type. Si no viene redirigir a la página de inicio
      if (defined('ICL_LANGUAGE_CODE')) {
      //comprobar si está instalado el plugin wmpl
        $id = icl_object_id($id_page_details, 'page', false, ICL_LANGUAGE_CODE);
        if ($id) {
          $id_page_details = $id;
        }
      } else {
        if (function_exists('pll_current_language')) {
          //Polylang
          if (function_exists('pll_get_post'))  {
            $id =  pll_get_post($id_page_details,  pll_current_language());
            if ($id) {
              $id_page_details = $id;
            }
          }
        }
      }
  
      if ($query->query_vars['page_id']==$id_page_details) {
        if (isset($query->query_vars['ref_property']) && $query->query_vars['ref_property']!='') {
          $this->juaala_rso_property_page(); 
        }
        //Deshabilitar el YOAST SEO para que no nos meta su tìtulo y meta el de detalle de propiedad
        //fuente: https://gist.github.com/kasparsd/5574458
        if ( class_exists('WPSEO_Frontend') ) {
          $wpseo_front = WPSEO_Frontend::get_instance();
          remove_filter( 'pre_get_document_title', array( $wpseo_front, 'title' ), 15 );
          remove_filter( 'wp_title', array( $wpseo_front, 'title' ), 15 );
        } 
        // remove extra theme filter
        remove_filter( 'pre_get_document_title', 'elegant_titles_filter' );
      }
    }
  }

  public function custom_title_property_details($title_parts) {
    global $property_title;
    if ($property_title!='') {
      $title_parts['title'] = $property_title;
    }
    return $title_parts;
  }

  public function juaala_rso_custom_shortcode_atts_wpcf7_filter( $out, $pairs, $atts ) {
    $my_attr = 'property_email';
    if ( isset( $atts[$my_attr] ) ) {
      $out[$my_attr] = $atts[$my_attr];
    }
    return $out;
  }

  public function juaala_rso_wpcf7_parse_property_field($cf7) { 
    // get the contact form object
    $wpcf = WPCF7_ContactForm::get_current();
  
    // if you wanna check the ID of the Form $wpcf->id
    $id_contact_form_contact = esc_attr( get_option( 'rojuaala-id-contact-form-7-property' ) );
  
    $id_form_lang = '';
   
    if (defined('ICL_LANGUAGE_CODE')) {
      //comprobar si está instalado el plugin wmpl
      $_type  = get_post_type($wpcf);
      $id = icl_object_id($wpcf->id, $_type, false, ICL_LANGUAGE_CODE);
      if ($id) {
        $id_form_lang = $id;
      }
    }

    if ($wpcf->id==$id_contact_form_contact || $id_form_lang!='') {
      if (isset($_POST['property_email'])) {
        $table_property = $_POST['property_email'];  
        $table_property_decode = base64_decode($table_property);
        $mail = $wpcf->prop('mail'); // returns array 
        $mail2 = $wpcf->prop('mail_2'); // returns array 
  
        if ($mail2) {
          $body2 = $mail2['body'];
          $body2_replace = str_replace("[property_email]", $table_property_decode, $body2);
          $mail2['body'] = $body2_replace;
          $wpcf->set_properties( array( 'mail_2' => $mail2 ));
        }
        $body = $mail['body'];
        //sustituir [property_email] por lo que contiene $table_property
        $body_replace = str_replace("[property_email]", $table_property_decode, $body);
        $mail['body'] = $body_replace ;
        $wpcf->set_properties( array( 'mail' => $mail ));
      }
    }
  
    return $wpcf;
  } 

  public function juaala_rso_property_email_info($property, $title, $price, $url,$base64=true) {

    $precio2_email = "";
    $url_email = $url;
    $ref_email =  (isset($property['AgencyRef']) && $property['OwnProperty']==1 && $property['AgencyRef']!='') ? $property['AgencyRef'] : $property['Reference'];
    $href= "<a href='$url_email' target='_blank'>$ref_email</a>";
    $reference_email = "<b>" . __('REF.','rsonline-juaala') . ": </b>" . $href;
    if ($price!=0) {
      $precio2_email = "<b>" . __('Price','rsonline-juaala') . ": </b>" . $price;;
    }
    $tipo_email = "<b>" . __('Property type','rsonline-juaala') . ": </b>" . $property['PropertyType']['NameType'];
    $habitaciones_email = "";
    if ($property['Bedrooms']!=0) {
      $habitaciones_email = "<b>" . __('Bedrooms','rsonline-juaala') . ": </b>" . $property['Bedrooms'];
    }
    $banos_email= "";
    if ($property['Bathrooms']!=0) {
      $banos_email =  "<b>" . __('Bathrooms','rsonline-juaala') . ": </b>" . $property['Bathrooms'];
    }
    $ubicacion_email = "<b>" . __('Location','rsonline-juaala') . ": </b>" . $property['Location'];
    $area_const_email = "";
    if ($property['Built']!=0) {
      $area_const_email = "<b>" . __('Built Area','rsonline-juaala') . ": </b>" . $property['Built'] . " m<sup>2</sup>";
    }
    $terraza_const_email = "";
    if ($property['Terrace']!=0) {
      $terraza_const_email = "<b>" . __('Terrace','rsonline-juaala') . ": </b>" . $property['Terrace'] . " m<sup>2</sup>";;
    }
    $sup_jardin_email = "";
    if ($property['GardenPlot']!=0) {
      $sup_jardin_email = "<b>" . __('Garden Plot','rsonline-juaala') . ": </b>" . $property['GardenPlot'] . " m<sup>2</sup>";
    }
  
    $property_email = "<h3  style='margin-top:0;margin-bottom:14px'><b>$title</b></h3>
                        <p>$reference_email</p>
                        <p>$precio2_email</p>
                        <p>$habitaciones_email</p>
                        <p>$banos_email</p>
                        <p>$tipo_email</p>
                        <p>$ubicacion_email</p>
                        <p>$area_const_email</p>
                        <p>$terraza_const_email</p>
                        <p>$sup_jardin_email</p><hr>";
  
      if ($base64) {
        $property_email = base64_encode($property_email);
      }
      return $property_email;
  }

  function juaala_wpf_dev_register_smarttag( $tags ) {
 
    // Key is the tag, item is the tag name.
    $tags[ 'property_email' ] = 'Property';
 
    return $tags;
}

 
  /**
   * Process the Smart Tag.
   *
   * @link   https://wpforms.com/developers/how-to-create-a-custom-smart-tag/
   */

  function juaala_wpf_dev_process_smarttag( $content, $tag ) {

    // Only run if it is our desired tag.
    if ( 'property_email' === $tag ) {
      global $wp;
      //$url =  home_url( $wp->request );
      //global $wp;
      $url = add_query_arg( $wp->query_vars, home_url( $wp->request ) );
      $url = wp_get_referer();
      // Replace the tag with our link.
      $content = str_replace( '{property_email}', $url, $content );
    }

    return $content;
  }
  //TODO
  function juaala_rso_wpf_dev_process_before($entry, $form_data)
  {
    //mandar lead a resales online con los datos del formulario

  }



  public function redirect_direct_access( ) {

    if (!is_admin()) {
  
      $id_page_details = 3334;
      $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-property-details' ) );
      if(isset($id_page_result_option) && $id_page_result_option!='') {
        if ( 'publish' === get_post_status( $id_page_result_option ) ) {
          $id_page_details = $id_page_result_option;
        }
      }
      global $wp_query;
  
      //comprobar si viene el parametro ref_property y type. Si no viene redirigir a la página de inicio
  
      if (defined('ICL_LANGUAGE_CODE')) {
      //comprobar si está instalado el plugin wmpl
        $id = icl_object_id($id_page_details, 'page', false, ICL_LANGUAGE_CODE);
        if ($id) {
          $id_page_details = $id;
        }
      } else {
        if (function_exists('pll_current_language')) {
          //Polylang
          if (function_exists('pll_get_post'))  {
            $id =  pll_get_post($id_page_details,  pll_current_language());
            if ($id) {
              $id_page_details = $id;
            }
          }
        }
      }
  
      $post_id = get_the_ID();
  
      if ( 
        $post_id == $id_page_details &&
        !isset($wp_query->query_vars['ref_property'])) { 
            $url_home = get_home_url();
            wp_redirect( $url_home );
            exit();
        }
    }
  }

  public function get_shortlist_properties($ajax=true,$class, $template,$view_type='card') {
    // Check if cookie is already set
    $properties= [];
    $response_properties['Property'] = [];
    $property_email_shortlist = '';
    $lang_request = $this->get_locale_page_rso_juaala();
   
    if (!$ajax) {
      $class_short=$class;
    } else {
      $class_short=$_GET['class'];
    }
    if(isset($_COOKIE['wpb_rso-juaala_shortlist'])) {

      
      //lista de propiedades seteada
      $properties = json_decode(stripslashes($_COOKIE['wpb_rso-juaala_shortlist']), true);
      
      
      foreach($properties as $property) {
        
        if ($property) {
  
          $porciones = explode(";", $property);
          //hacemos llamada para buscar la propiedad
          
          $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
          $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
       
          $initParams = array(
            'P_ApiId' => $porciones[1],
            'p1' => $rojuaala_client_id,
            'p2' => $rojuaala_api_key,
            'P_RefId' =>  $porciones[0],
            'P_Lang' => $lang_request
          );
  
          $apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
          $response = $apiController->getRequest($initParams,'getProperty');
          if (isset($response['Property'])) {
            //añadimos a la lista de shortlist
            $response['Property']['id_filter'] = $porciones[1];
            $response_properties['Property'][] = $response['Property'];
            $type_title_property_shortlist = "";
            if (isset($response['Property']['Price'])) { 
              //venta
              $type_title_property_shortlist = __(" for sale ",'rsonline-juaala');
            } else if (isset($response['Property']['RentalPrice1'])) {
              //alquiler
              $type_title_property_shortlist = __(" for rent ",'rsonline-juaala');
            }
            if (isset($response['Property']['Price'])) {
              //venta
              $price_property_shortlist = $response['Property']['Price'];
              if(is_numeric($response['Property']['Price'])) {
                $price_property_shortlist = number_format($response['Property']['Price'],0,'.',',');
              }
            }
  
            if (isset($response['Property']['RentalPrice1'])) {
              //Alquiler
              $price_property_shortlist = $response['Property']['RentalPrice1'];
              if(is_numeric($response['Property']['RentalPrice1'])) {
                $price_property_shortlist = number_format($response['Property']['RentalPrice1'],0,'.',',');
              }
              $price_property_shortlist = $price_property_shortlist . " € /" .  __($response['Property']['RentalPeriod'],'rsonline-juaala');
            } 
  
            $title_property_shortlist = $response['Property']['PropertyType']['NameType'] .  $type_title_property_shortlist . ' ' . __('in','rsonline-juaala') . ' ' . $response['Property']['Location'] . ', ' . $response['Property']['Area'];
  
            $url_property_email = $this->get_url_details_property(sanitize_title($title_property_shortlist), $response['Property']['Reference'],$porciones[1]);
     
            $property_email_shortlist =   $property_email_shortlist . $this->juaala_rso_property_email_info($response['Property'],$title_property_shortlist,$price_property_shortlist,$url_property_email,false);
          }
        }
      }


      $property_email_shortlist = base64_encode($property_email_shortlist);

      
  
      $rs_juaala_templates_params = new stdClass();
      $rs_juaala_templates_params->rs_juaala_sresults_properties_search =$response_properties['Property'];  
      $rs_juaala_templates_params->rs_juaala_sresults_query_search = [];
      $rs_juaala_templates_params->rs_juaala_spage_rs = null;
      $rs_juaala_templates_params->rs_juaala_sresults_query_class =  $class_short;
      $rs_juaala_templates_params->rs_juaala_sresults_init_params = [];
      $rs_juaala_templates_params->rs_juaala_incluse_search = false;
      $rs_juaala_templates_params->rs_juaala_include_pagination = 0;
      $rs_juaala_templates_params->rs_juaala_include_sort = false;
      $rs_juaala_templates_params->rs_juaala_include_num_results = false;
      $rs_juaala_templates_params->rs_juaala_view_type = $view_type;  
      $rs_juaala_templates_params->rs_juaala_sresults_is_shortlist = true;  
      $rs_juaala_templates_params->rs_request_uri = $_SERVER["REQUEST_URI"];  
      $rs_juaala_templates_params->rs_request_url = plugin_dir_url(__DIR__);
      $rs_juaala_templates_params->rs_request_url_shortcode = plugin_dir_url(__DIR__) . 'do_shorcode/';
      $rs_juaala_templates_params->rs_get = $_GET;  
      $rs_juaala_templates_params->cut_description_property = CUT_DESCRIPTION_PROPERTY;
      $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
      $rs_juaala_templates_params->cookies =  $_COOKIE;
      $rs_juaala_templates_params->P_Lang = $lang_request;
      $rs_juaala_templates_params->template = $template;

      
      
      $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      
      $html_shortlist = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateProperties');

      $html_form_contact = '';
  
      $id_contact_form = esc_attr( get_option( 'rojuaala-id-contact-form-7-property' ) );
      
      if (isset($id_contact_form) && $id_contact_form!='' && count($response_properties['Property'])>0 ) {
        $html_form_contact = '
          <div id="property-contact-form" class="mt-4 pt-4 px-3 property-contact-form mx-auto container shortlist">
            <h4 class="title-property-contact-form mb-0 py-1  font-weight-light">
          ' . __('Request Information','rsonline-juaala') . '</h4> 
            <p class="description-property-contact-form">' .
            __('To receive more information about this property, please enter the details below. <br>* are required fields','rsonline-juaala') .
            '</p>' .
            do_shortcode( '[contact-form-7 id="' . $id_contact_form . '" property_email="'. $property_email_shortlist . '" title="Propiedad"]' ) .
          '</div>';
      }
      if ($ajax) {
        wp_send_json_success($html_shortlist.$html_form_contact);
      } else {
        return $html_shortlist.$html_form_contact;
      }
    }
  
  }

  public function set_property_shortlist() {
    $nueva=[];
    $nueva_deleted = [];
    $ref = $_GET['ref'];
    $filter = $_GET['filter'];
    if (isset($_COOKIE['wpb_rso-juaala_shortlist'])) {
      $nueva = json_decode(stripslashes($_COOKIE['wpb_rso-juaala_shortlist']), true);
      //eliminamos la actual si la tuviese
      $nueva_deleted = \array_diff($nueva, [$ref . ";" . $filter]);
      unset($_COOKIE['wpb_rso-juaala_shortlist']); 
    } else {
    }
    $nueva_deleted[] = $ref . ";" . $filter;
    // Set the cookie
    setcookie('wpb_rso-juaala_shortlist',  json_encode($nueva_deleted), time()+31556926,"/");
    wp_send_json(count($nueva_deleted));
  }

  public function remove_property_shortlist() {
    $ref = $_GET['ref'];
    $filter = $_GET['filter'];
    $nueva=[];
    $nueva_deleted = [];
    if (isset($_COOKIE['wpb_rso-juaala_shortlist'])) {
     // $nueva = $_COOKIE['wpb_rso-juaala_shortlist'];
      $nueva = json_decode(stripslashes($_COOKIE['wpb_rso-juaala_shortlist']), true);
      unset($_COOKIE['wpb_rso-juaala_shortlist']); 
      $nueva_deleted = \array_diff($nueva, [$ref . ";" . $filter]);
    }
    // Set the cookie
    setcookie('wpb_rso-juaala_shortlist', json_encode($nueva_deleted), time()+31556926,"/");
  
    wp_send_json(count($nueva_deleted));
  }

  public function write_shorlist( ) {

    $id_page_shortlist = 13335;
    $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-shortlist' ) );
    if(isset($id_page_result_option) && $id_page_result_option!='') {
      if ( 'publish' === get_post_status( $id_page_result_option ) ) {
        $id_page_shortlist = $id_page_result_option;
      }
    }

    if (defined('ICL_LANGUAGE_CODE')) {
      //comprobar si está instalado el plugin wmpl
      $id = icl_object_id($id_page_shortlist, 'page', false, ICL_LANGUAGE_CODE);
      if ($id) {
        $id_page_shortlist = $id;
      }
    } else { 
      if (function_exists('pll_current_language')) {
        if (function_exists('pll_get_post'))  {
          $id =  pll_get_post($id_page_shortlist,  pll_current_language());
          if ($id) {
            $id_page_shortlist = $id;
          }
        }
      }
    }
  
    $page_link = "";
    if ($id_page_shortlist) {
      $page_link = get_page_link($id_page_shortlist);
    }
    set_query_var ('page_shortlist_rso_juaala', $page_link);
    set_query_var ('class', 'fixed');
  
    ob_start();
    include __DIR__ . '/partials/rsonline-juaala-widget-shortlist.php';
    echo ob_get_clean();
  }

  public function set_property_compare() {
    $nueva=[];
    $nueva_deleted = [];
    $ref = $_GET['ref'];
    $filter = $_GET['filter'];
    if (isset($_COOKIE['wpb_rso_juaala_compare'])) {
      $nueva = json_decode(stripslashes($_COOKIE['wpb_rso_juaala_compare']), true);
      //eliminamos la actual si la tuviese
      $nueva_deleted = \array_diff($nueva, [$ref . ";" . $filter]);
      unset($_COOKIE['wpb_rso_juaala_compare']); 
    } else {
    }
    $nueva_deleted[] = $ref . ";" . $filter;
    // Set the cookie
    setcookie('wpb_rso_juaala_compare',  json_encode($nueva_deleted), time()+31556926,"/");
    wp_send_json(count($nueva_deleted));
  }

  public function remove_property_compare() {
    $ref = $_GET['ref'];
    $filter = $_GET['filter'];
    $nueva=[];
    $nueva_deleted = [];
    if (isset($_COOKIE['wpb_rso_juaala_compare'])) {
     // $nueva = $_COOKIE['wpb_rso-juaala_shortlist'];
      $nueva = json_decode(stripslashes($_COOKIE['wpb_rso_juaala_compare']), true);
      unset($_COOKIE['wpb_rso_juaala_compare']); 
      $nueva_deleted = \array_diff($nueva, [$ref . ";" . $filter]);
    }
    // Set the cookie
    setcookie('wpb_rso_juaala_compare', json_encode($nueva_deleted), time()+31556926,"/");
  
    wp_send_json(count($nueva_deleted));
  }

  public function write_compare_list( ) {

    $id_page_compare_list = 15335;
    $id_page_result_option = esc_attr( get_option( 'rojuaala-field-id-page-compare_list' ) );
    if(isset($id_page_result_option) && $id_page_result_option!='') {
      if ( 'publish' === get_post_status( $id_page_result_option ) ) {
        $id_page_compare_list = $id_page_result_option;
      }
    }

    if (defined('ICL_LANGUAGE_CODE')) {
      //comprobar si está instalado el plugin wmpl
      $id = icl_object_id($id_page_compare_list, 'page', false, ICL_LANGUAGE_CODE);
      if ($id) {
        $id_page_compare_list = $id;
      }
    } else { 
      if (function_exists('pll_current_language')) {
        if (function_exists('pll_get_post'))  {
          $id =  pll_get_post($id_page_compare_list,  pll_current_language());
          if ($id) {
            $id_page_compare_list = $id;
          }
        }
      }
    }
  
    $page_link = "";
    if ($id_page_compare_list) {
      $page_link = get_page_link($id_page_compare_list);
    }
    set_query_var ('page_compare_list_rso_juaala', $page_link);
    set_query_var ('class', 'fixed');
  
    ob_start();
    include __DIR__ . '/partials/rsonline-juaala-widget-compare.php';
    echo ob_get_clean();
  }

  public function get_number_properties() {

    $others_params = [];
    $lang_request = $this->get_locale_page_rso_juaala();
    $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
    $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
 
    //recoger parametros
 
   if (isset($_GET['type'])) {
     $type = $_GET['type'];
     if (is_array($type)) {
       $type =implode(",", $type);
     } 
     $others_params['P_PropertyTypes'] = $type;
   }
 
   if (isset($_GET['location'])) {
     $location = $_GET['location'];
     if (is_array($location)) {
       $location =implode(",", $location);
     }
     $others_params['P_Location'] = $location;
   }
 
   if (isset($_GET['price_from'])) {
     $price_from = $_GET['price_from'];
     $others_params['P_Min'] = $price_from;
   }
 
   if (isset($_GET['price_to'])) {
     $price_to = $_GET['price_to'];
     $others_params['P_Max'] = $price_to;
   }
 
   if (isset($_GET['beds'])) {
     $beds = $_GET['beds'];
     $others_params['P_Beds'] = $beds;
   }
 
   if (isset($_GET['baths'])) {
     $baths = $_GET['baths'];
     $others_params['P_Baths'] = $baths;
     
   }
  //parametros del buscador avanzado       
  //obtener la lista del buscador avanzado. Viene con parametros llamado features
  foreach ($_GET as $key=>$value) {
    $pos = strrpos($key, "features");
    if ($pos !== false) { 
      if (is_array($value)) {
        foreach($value as $v) {
          $others_params[$v] = "1";
        }
      } else {
        $others_params[$value] = "1";
      }
      
     
    }
  }

  if (isset($_GET['P_MustHaveFeatures'])) {
    $others_params['P_MustHaveFeatures'] = $_GET['P_MustHaveFeatures'];
  }

  if (isset($_GET['p_new_devs'])) {
    $others_params['p_new_devs'] = $_GET['p_new_devs'];
  }
 
   $initParams = array(
     'P_ApiId' => $_GET['filter_id'],
     'p1' => $rojuaala_client_id,
     'p2' => $rojuaala_api_key,
     'P_Lang' => $lang_request
   );
 
   $initParams = array_merge($initParams,$others_params);
 
   $apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
 
   $response = $apiController->getRequest($initParams, 'getProperties');
 
   if ($response) {
     if($response['QueryInfo']) {
       if ($response['QueryInfo']['PropertyCount']) {
         wp_send_json( array('number' => $response['QueryInfo']['PropertyCount']) );
       }
     } else {
       wp_send_json( array('number' => '0') );
     }
   } else {
     wp_send_json( array('number' => '0') );
   }
 }

  public function get_map_property() {
    //show Map Property
    echo do_shortcode('[leaflet-map zoom=2 zoomcontrol doubleClickZoom height=300 scrollwheel]',true);
  }

  public function get_property_pdf($ref_property,$type,$logov) {

    global $details_property;
    global $wp_query;

    $wp_query->query_vars['ref_property'] = $ref_property;
    if (isset($wp_query->query_vars['ref_property']) && $wp_query->query_vars['ref_property']!='') {
      $this->juaala_rso_property_page();
    }
    $rs_juaala_templates_params = new stdClass();
    $rs_juaala_templates_params->rs_juaala_property_details = $details_property;

    if ( get_option('rojuaala-image-pdf')=='') {
      $image = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );
      $image_src_pdf = $image[0];
    } else {
      $image_src_pdf = get_option('rojuaala-image-pdf');
    }

    $rs_juaala_templates_params->image_src_pdf = $image_src_pdf;
    $rs_juaala_templates_params->text_contact_pdf = get_option( 'rojuaala-text-contact-pdf' );
    $rs_juaala_templates_params->text_footer_pdf =  get_option( 'rojuaala-text-footer-pdf' );
    $lang_request = $this->get_locale_page_rso_juaala();
    $rs_juaala_templates_params->P_Lang = $lang_request;

    $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
    $pdf = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplatePropertyPDF');
    return $pdf;
  }

  public function get_releated_properties() {

    try {

  
      $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
      $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
      $api_id = $_GET['params']['api_id'];
      $template = isset($_GET['params']['template']) ? $_GET['params']['template'] : '';
      $lang_request = $this->get_locale_page_rso_juaala();

      $price = 0;

      if(isset( $_GET['params']['price'])) {
        $price = $_GET['params']['price'];
        $price = (float) str_replace(",", "", $price);
      }

      //calculamos el precio por abajo
      $price_from= $price - ((20 * $price)/100);

      //calculamos el precio por arriba
      $price_to = $price + ((20 * $price)/100);

      $initParamsReleated = array(
        'P_ApiId' => $api_id,
        'p1' => $rojuaala_client_id,
        'p2' => $rojuaala_api_key,
        'P_Lang' => $lang_request,
        'P_Max' => $price_to,
        'P_Min' =>  $price_from,
        'P_PropertyTypes' =>  $_GET['params']['type_id'],
        'P_Area' => $_GET['params']['area'],
        'p_Image' => 1,
        'p_PageSize' => 5
      );

    
      $apiControllerFeatured = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
      $responseReleated = $apiControllerFeatured->getRequest($initParamsReleated, 'getProperties');
    
      $rs_juaala_sresults_properties_sidebar_c = $responseReleated['Property'];
      $rs_juaala_sresults_properties_sidebar = array_slice ($rs_juaala_sresults_properties_sidebar_c, 0, 5);
      
      $rs_juaala_templates_params = new stdClass();
      $rs_juaala_templates_params->cookies =  $_COOKIE;
      $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar = $rs_juaala_sresults_properties_sidebar;
      $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar_id_api = $api_id;
      $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
      $rs_juaala_templates_params->P_Lang = $lang_request;
      $rs_juaala_templates_params->template = $template;

    
      $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      $html = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateReleated');
    
      $html = "" . $html;
      
      $return = array(
        'html'  => $html,
      );
      wp_send_json_success($return);
    } catch(Exception $e) {
      $return = array(
        'html'  => "Error al recuperar las propiedades relacionadas",
      );
      wp_send_json_success($return);
    }
  
  }

  public function get_features_properties() {

    $id_featured_properties = $_GET['id_featured_properties'];
    $template = isset($_GET['template']) ?  $_GET['template'] : '';
    $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
    $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
    $lang_request = $this->get_locale_page_rso_juaala();
   
    //buscamos propiedades destacadas
    $initParamsFeatured = array(
      'P_ApiId' => $id_featured_properties,
      'p1' => $rojuaala_client_id,
      'p2' => $rojuaala_api_key,
      'P_Lang' => $lang_request,
      'P_SortType' => '3'
    );
  
    $apiControllerFeatured = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
  
    $responseFeatured = $apiControllerFeatured->getRequest($initParamsFeatured, 'getProperties');
  
    $rs_juaala_sresults_properties_sidebar_c = $responseFeatured['Property'];
    $rs_juaala_sresults_properties_sidebar = array_slice ($rs_juaala_sresults_properties_sidebar_c, 0, 5);
    
    $rs_juaala_templates_params = new stdClass();
    $rs_juaala_templates_params->cookies =  $_COOKIE;
    $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar = $rs_juaala_sresults_properties_sidebar;
    $rs_juaala_templates_params->rs_juaala_sresults_properties_sidebar_id_api = $id_featured_properties;
    $rs_juaala_templates_params->url_base_details_property =  $this->get_url_details_property_template();
    $rs_juaala_templates_params->P_Lang = $lang_request;
    $rs_juaala_templates_params->template = $template;
  
    $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
    $html_sidebar = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateSidebar');
  
    $html_sidebar = "" . $html_sidebar;
    
    $return = array(
      'html_siderbar'  => $html_sidebar,
    );
    wp_send_json_success($return);
  
  }

  public function juaala_rso_property_page($atts=[]) {
    global $property_title;
  
    if (!is_admin()) {
      global $wp_query;
      global $details_property;
      if (count($atts)==0) {
        if(isset($wp_query->query_vars['ref_property'])) {
          $ref_property = urldecode($wp_query->query_vars['ref_property']);
        }
    
        $P_ApiId = $_GET['type'];
      } else {
        if (isset($atts['filter_id']) && isset($atts['reference'])) {
          $P_ApiId = $atts['filter_id'];
          $ref_property = $atts['reference'];
        }
      }
  
      $rojuaala_api_key = esc_attr( get_option( 'rojuaala-api-key' ) );
      $rojuaala_client_id = esc_attr( get_option( 'rojuaala-client-id' ) );
  
  
      $lang_request = $this->get_locale_page_rso_juaala();
  
      $initParams = array(
        'P_ApiId' => $P_ApiId,
        'p1' => $rojuaala_client_id,
        'p2' => $rojuaala_api_key,
        'P_RefId' => $ref_property,
        'P_Lang' => $lang_request,
        'P_VirtualTours' => 1,
        'P_ShowGPSCoords' => 1
      );
  
  
      $apiController = new Rsonline_Juaala_Api_Controller(URL_API_RESALES_ONLINE_V6, ENDPOINTS_API_RESALES_ONLINE_V6);
  
      $response = $apiController->getRequest($initParams,'getProperty');
      if (isset($response['Property'])) {
  
        $details_property = $response['Property'];
  
        $title = $details_property['PropertyType']['NameType'] . ' ' . __('in','rsonline-juaala') . ' ' . $details_property['Location'] . ', ' . $details_property['Area'];
        $property_title = $title;
        
      } else {
        ob_start();
        include __DIR__ . '/partials/property_details_not_found.php';
        return ob_get_clean(); 
      }
    }
  }

  function juaala_rso_screen_properties($atts)  {
    try {
      if (isset($atts['path'])) {
        $path_export = $atts['path'];
      } else {
        if (defined('EXPORT_PATH_SCREEN')) {
          $path_export = EXPORT_PATH_SCREEN;
        } else {
          $path_export = 'exports';
        }
      }

      $interval = "10000"; //10 segundos
      if (isset($atts['interval'])) {
        $interval = $atts['interval'];
      }
      
      $dir_path = ABSPATH . $path_export . '/*.jpg';
      $rs_juaala_templates_params = new stdClass();
      $rs_juaala_templates_params->replace = ABSPATH;
      $rs_juaala_templates_params->images = glob($dir_path);
      $rs_juaala_templates_params->url_site =  get_site_url();
      $rs_juaala_templates_params->interval =  $interval;
      if (isset($atts['template']) && $atts['template']!='') {
        $rs_juaala_templates_params->template = $atts['template'];
      }

      $templatesController = new Rsonline_Juaala_Template_Controller(URL_API_JUAALA_RESALES, ENDPOINTS_API_JUAALA_RESALES);
      $html_screen = $templatesController->getTemplate($rs_juaala_templates_params,'getTemplateScreen');
      return $html_screen;
      } catch(Exception $e) {
        return "Error Screen";
      }
  }

  function juaala_get_options_advanced_search(&$rs_juaala_search_form,$atts) {
    $array_options = ['setting','orientation','condition','pool','climate_control',
      'views','features','furniture','kitchen','garden','security',
      'parking','utilities','category','plots_and_ventures','rentals'];

    foreach($array_options as $o) {
      //echo 'no_show_adv_' . $o . '="true"<br>';
      if (isset($atts["no_show_adv_" . $o]) && $atts["no_show_adv_" . $o]=="true") {
        $rs_juaala_search_form->{"no_show_adv_" . $o} = $atts["no_show_adv_" . $o];
      }
    }
  }


}
