(function( $ ) {
	'use strict';


	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */




	$( document ).ready(function() {
		$( ".more-desription-property" ).click(function() {
			var state = $(this).data('state');
			var classContentExtended = 'description-property-extended';
			var classPositionExtended = 'description-property-more-extended';
			var label_close = $(this).data('close');
			var label_open = $(this).data('open');
			if (state=='open') {
				$(this).data('state','close');
				$('#description-property').removeClass(classContentExtended);
				$('#description-property-more').removeClass(classPositionExtended);
				
				$(this).html(label_open);
			} else {
				$(this).data('state','open');
				$('#description-property').addClass(classContentExtended);
				$('#description-property-more').addClass(classPositionExtended);
				$(this).html(label_close);
			}
			return false;
		});
	
	
		$(".more-information-request-property").on('click', function(event) {
	
			if (this.hash !== "") {
				// Prevent default anchor click behavior
				event.preventDefault();
				// Store hash
				var hash = this.hash;
				// Using jQuery's animate() method to add smooth page scroll
				// The optional number (800) specifies the number of milliseconds it takes to scroll to the specified area
				$('html, body').animate({
					scrollTop: $(hash).offset().top - 90
				}, 800, function(){
					// Add hash (#) to URL when done scrolling (default click behavior)
					window.location.hash = hash;
				});
			} // End if
			return false;
		});
	
		$("body .action-shortlist-property").on("click", actionPropertyShortList);
    $("body .action-compare-property").on("click", actionPropertyCompare);
	});


})( jQuery );


function refreshNumProperties(filter_id, params ,id_html_refresh, legend){

  var data = {
    action: "get_number_properties", 
    'filter_id': filter_id
  }
 
 const data_request = Object.assign({}, data, params);

 jQuery(id_html_refresh).html('<div class="spinner-border" role="status"><span class="sr-only">Loading...</span></div>')

  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data_request,
    success: function(data,status,xhr) {
      if (data.number!=undefined && data.number!=undefined) {
        jQuery(id_html_refresh).html(data.number + ' ' + legend);
      } else {
       jQuery(id_html_refresh).html('0' + ' ' + legend);
      }
    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
      jQuery(id_html_refresh).html('0' + ' ' + legend);
    }
  });
}

function loadMapProperty(){

  var data = {
    action: "get_map_property"
  }
 
 const data_request = Object.assign({}, data);

  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data_request,
    success: function(data,status,xhr) {
      console.log(data)
    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
      console.log(errorMessage)
    }
  });
}


function actionPropertyShortList() {
  var element = jQuery(this);
  if (element.hasClass( "remove-shortlist-property" )) {
    removePropertyShortList(element);
  } else if (element.hasClass( "add-shortlist-property" )) {
    addPropertyShortList(element);
    
  }
}

function addPropertyShortList(element) {
  var ref = element.data('ref');
  var filter = element.data('filter');
  var label = element.data('label')
  var data = {
    action: "set_property_shortlist", 
    'ref': ref,
    'filter':filter
  };
  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data,
    success: function(data,status,xhr) {
      element.addClass('remove-shortlist-property');
      element.removeClass('add-shortlist-property');
      var before = jQuery('span',element).html();
      element.data('label',before);
      jQuery('span',element).html(label);
      var icon = jQuery('i',element);
      icon.addClass('fas');
      icon.removeClass('far');
      var label_number = jQuery("#num_shortlist_juaala");
      if (label_number) {
        var number_current = label_number.html();
        number_current++;
        label_number.html(number_current);
        //poner visible el shortlist
        jQuery("#widget-shortlist-rso-juaala").css("display","block");
      }
    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
     
    }
  });
}

function removePropertyShortList(element) {
  var ref = element.data('ref');
  var filter = element.data('filter');
  var label = element.data('label');
  var refresh = element.data('refresh');
  var data = {
    action: "remove_property_shortlist", 
    'ref': ref,
    'filter':filter
  };
  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data,
    success: function(data,status,xhr) {
      element.addClass('add-shortlist-property');
      element.removeClass('remove-shortlist-property');
      var before = jQuery('span',element).html();
      element.data('label',before);
      jQuery('span',element).html(label);
      var icon = jQuery('i',element);
      icon.addClass('far');
      icon.removeClass('fas');
      var label_number = jQuery("#num_shortlist_juaala");
      if (label_number) {
        var number_current = label_number.html();
        number_current--;
        label_number.html(number_current);
        //poner invisible si es 0 el shortlist
        if (number_current==0) {
          jQuery("#widget-shortlist-rso-juaala").css("display","none");
        }
      }
      if (refresh!=null && refresh==true)  {
        window.location.reload();
      }

    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
     
    }
  });

}

function actionPropertyCompare() {
  var element = jQuery(this);
  if (element.hasClass( "remove-compare-property" )) {
    removePropertyCompare(element);
  } else if (element.hasClass( "add-compare-property" )) {
    addPropertyCompare(element);
    
  }
}

function addPropertyCompare(element) {
  var ref = element.data('ref');
  var filter = element.data('filter');
  var label = element.data('label')
  var data = {
    action: "set_property_compare", 
    'ref': ref,
    'filter':filter
  };
  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data,
    success: function(data,status,xhr) {
      element.addClass('remove-compare-property');
      element.addClass('text-success');
      element.removeClass('add-compare-property');
      element.removeClass('text-light');
      var before = jQuery('span',element).html();
      element.data('label',before);
      jQuery('span',element).html(label);
      var label_number = jQuery("#num_compare_juaala");
      if (label_number) {
        var number_current = label_number.html();
        number_current++;
        label_number.html(number_current);
        //poner visible el shortlist
        jQuery("#widget-compare-rso-juaala").css("display","block");
      }
    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
     
    }
  });
}

function removePropertyCompare(element) {
  var ref = element.data('ref');
  var filter = element.data('filter');
  var label = element.data('label');
  var refresh = element.data('refresh');
  var data = {
    action: "remove_property_compare", 
    'ref': ref,
    'filter':filter
  };
  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data,
    success: function(data,status,xhr) {
      element.addClass('add-compare-property');
      element.addClass('text-light');
      element.removeClass('remove-compare-property');
      element.removeClass('text-success');
      var before = jQuery('span',element).html();
      element.data('label',before);
      jQuery('span',element).html(label);
      var label_number = jQuery("#num_compare_juaala");
      if (label_number) {
        var number_current = label_number.html();
        number_current--;
        label_number.html(number_current);
        //poner invisible si es 0 el compare
        if (number_current==0) {
          jQuery("#widget-compare-rso-juaala").css("display","none");
        }
      }
      if (refresh!=null && refresh==true)  {
        window.location.reload();
      }
    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
     
    }
  });

}


function initGoogleMapProperty() {
  var map = new google.maps.Map(document.getElementById('map'), {
    zoom: 13,
    center: {lat: 36.500769, lng: -5.0050844}
  });
  var geocoder = new google.maps.Geocoder();
  geocoder.geocode({'address': location_property}, function(results, status) {
    if (status === 'OK') {
      map.setCenter(results[0].geometry.location);
      var cityCircle = new google.maps.Circle({
        strokeColor: 'gray',
        strokeOpacity: 0,
        strokeWeight: 0,
        fillColor: '#ccc',
        fillOpacity: 0.6,
        map: map,
        center: results[0].geometry.location,
        radius: 1400
      });
  
    } else {
      //ocultamos el mapa
      var m = jQuery("#map");
      if (m!=undefined) {
        m.addClass("d-none");
      }
    }
  });

 


}

function get_property_pdf(ref_property, type, logo=false) {
  
  var data = {
    action: "get_property_pdf", 
    'ref_property': ref_property,
    'type': type,
    'logo': logo
    }
 
 const data_request = data;
 jQuery.ajax({
  url : wp_ajax_vars.ajax_url,
  data: data_request,
  success: function(data,status,xhr) {

    var blob = new Blob([data], {type: "application/pdf"});

    //var blob=new Blob([data]);
    var link=document.createElement('a');
    link.href=window.URL.createObjectURL(blob);
    link.download="propiedad.pdf";
    link.click();
  },
  error: function (jqXhr, textStatus, errorMessage) { // error callback 
    console.error("ERROR LLAMADA",errorMessage)
    //jQuery(id_html_refresh).html(errorMessage);
  }
});
}

function get_features_properties(id_featured_properties,id_html_refresh,template='') {
  var data = {
    action: "get_features_properties", 
    'id_featured_properties': id_featured_properties,
    'template': template
    }
 
 const data_request = data;

 jQuery(id_html_refresh).html('<div class="col-12 d-flex justify-content-center"><div class="mt-5 mx-auto spinner-border" role="status"><span class="sr-only">Loading...</span></div></div>')

  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data_request,
    success: function(data,status,xhr) {
      if (data!=undefined && data!='' && data.data!=undefined) {
        jQuery(id_html_refresh).html(data.data.html_siderbar);
      } else {
       jQuery(id_html_refresh).html('');
      }
      jQuery("body .action-shortlist-property").on("click", actionPropertyShortList);
      jQuery("body .action-compare-property").on("click", actionPropertyCompare);
    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
      jQuery(id_html_refresh).html(errorMessage);
    }
  });
}

function get_releated_properties(params,id_html_refresh,id_title) {
  var data = {
    action: "get_releated_properties", 
    params: params
  }
 const data_request = data;
 jQuery(id_html_refresh).html('<div class="col-12 d-flex justify-content-center "><div class="mt-5 mx-auto spinner-border" role="status"><span class="sr-only">Loading...</span></div></div>')

  jQuery.ajax({
    url : wp_ajax_vars.ajax_url,
    data: data_request,
    success: function(data,status,xhr) {

      if (data!=undefined && data!='' && data.data!=undefined) {
        jQuery(id_html_refresh).html(data.data.html);
        jQuery(id_title).removeClass( "d-none" );
      } else {
       jQuery(id_html_refresh).html('');
      }
      jQuery("body .action-shortlist-property").on("click", actionPropertyShortList);
      jQuery("body .action-compare-property").on("click", actionPropertyCompare);
    },
    error: function (jqXhr, textStatus, errorMessage) { // error callback 
      jQuery(id_html_refresh).html(errorMessage);
    }
  });
}

